%BatActivity:  This function examines activity patterns for Steve Presley.

function [ObsSea,PrSea,ObsHab,PrHab] = BatActivity(Data,Seasons,Habitat,Species,stat,Rmeth)

    if(nargin < 5)                                                                              % Allocate input arguments
        stat = [];
    end;
    if(nargin < 6)
        Rmeth = [];
    end;
    
    if(isempty(stat))                                                                           % Assign default values to input arguments
        stat = 1;
    end;
    if(isempty(Rmeth))
        Rmeth = 1;
    end;

    NumSea = length(unique1(Seasons));                                                          % Determine number of seasons
    NumHab = length(unique1(Habitat));                                                          % Determine number of habitats
    NumSpp = length(unique(Species));                                                           % Determine number of species
    
    ComSea = comb(NumSea,2);                                                                    % Calculate number of pairwise combinations of seasons
    ComHab = comb(NumHab,2);                                                                    % Calculate number of pairwise combinations of habitats
    ComSpp = comb(NumSpp,2);                                                                    % Calculate number of pairwise combinations of species
    
% Cycle through data to assess activity patterns between seasons

    ObsSea = zeros(NumHab,NumSpp);                                                              % Create output matirx for observed differences between seasons
    PrSea = zeros(NumHab,NumSpp);                                                               % Create output matrix for significance of observed values
    
    for b = 1:NumSpp                                                                            % Cycle through species
        for a = 1:NumHab                                                                        % Cycle through habitats
            for i = 1:(NumSea-1)                                                            
                for j = (i+1):NumSea
                    IndX = find(Species == b & Seasons == i & Habitat == a);                    % Pull out data corresponding to season X
                    IndY = find(Species == b & Seasons == j & Habitat == a);                    % Pull out data corresponding to season Y
                    X = Data(IndX);
                    Y = Data(IndY);
                    switch(Rmeth)
                        case(1)
                            [ObsSea(a,b),PrSea(a,b)] = distribdiff2(X,Y,stat,[],[],3,[]);       % Estimate observed difference and significance
                        case(2)
                            [ObsSea(a,b),PrSea(a,b)] = distribdiff2a(X,Y,stat,[],[],3,[]);      % Estimate observed difference and significance
                        case(3)
                            [ObsSea(a,b),PrSea(a,b)] = distribdiff2b(X,Y,stat,[],[],3,[]);      % Estimate observed difference and significance
                        case(4)
                            [ObsSea(a,b),PrSea(a,b)] = distribdiff2c(X,Y,stat,[],[],3,[]);      % Estimate observed difference and significance
                    end;
                end;
            end;
        end;
    end;

    
% Cycle through data to assess activity patterns between habitats
    
    ObsHab = zeros(ComHab,NumSpp);                                                              % Create output matirx for observed differences between habitats
    PrHab = zeros(ComHab,NumSpp);                                                               % Create output matrix for significance of observed values

    for b = 1:NumSpp
        Cnt = 0;
        for a = 1:(NumHab-1)
            IndH1S1 = find(Species == b & Habitat == a & Seasons == 1);                         % Pull out data for habitat 1 and sum across seasons
            IndH1S2 = find(Species == b & Habitat == a & Seasons == 2);
            H1 = rowsum([Data(IndH1S1) Data(IndH1S2)]);           
            for c = (a+1):NumHab
                Cnt = Cnt + 1;
                IndH2S1 = find(Species == b & Habitat == c & Seasons == 1);                     % Pull out data for habitat 2 and sum across seasons
                IndH2S2 = find(Species == b & Habitat == c & Seasons == 2);
                H2 = rowsum([Data(IndH2S1) Data(IndH2S2)]);
                switch(Rmeth)
                    case(1)
                        [ObsHab(Cnt,b),PrHab(Cnt,b)] = distribdiff2(H1,H2,stat,[],[],3,[]);     % Estimate observed differences and significance
                    case(2)
                        [ObsHab(Cnt,b),PrHab(Cnt,b)] = distribdiff2a(H1,H2,stat,[],[],3,[]);    % Estimate observed differences and significance
                    case(3)
                        [ObsHab(Cnt,b),PrHab(Cnt,b)] = distribdiff2b(H1,H2,stat,[],[],3,[]);    % Estimate observed differences and significance 
                    case(4)
                        [ObsHab(Cnt,b),PrHab(Cnt,b)] = distribdiff2c(H1,H2,stat,[],[],3,[]);    % Estimate observed differences and significance
                end;
            end;
        end;
    end;