% CA: Correspondence analysis of a contingency table of counts.
%
%     Usage: [V,W] = CA(X)
%
%          X = data matrix of counts
%          ---------------------------------------------------------------------
%          V = row scores - only rows after the first are of interest
%          W = column scores - only columns after the first are of interest
%
%   Chris Higgins 7/7/2004
%
% Pielou, E.C. 1984. The interpretation of ecological data: a primer on classification and ordination.
%   John Wiley & Sons. New York, NY. 263 pps.

function [V,W] = CA(X)

    r = rowsum(X);                                      % Calculate row totals
    c = sum(X);                                         % Calcuate column totals
    N = sum(sum(X));                                    % Calculate grand total

    R = diag(r);                                        % Create diagonal matrix whose nonzero elements are row totals
    C = diag(c);                                        % Create diagonal matrix whose nonzero elements are column totals
    
    M = R^(-1/2)*X*C^(-1/2);
    P = M*M';
    Q = M'*M;
    
    [evects,evals] = Eigen(P);                          % Peform eigenanalysis on the P matrix
    UP = evects';                                       % Transpose matrix to match Pielou's terminology
    [evects,evals] = Eigen(Q);                          % Peform eigenanalysis on the Q matrix
    UQ = evects';                                       % Transpose matrix to match Pielou's terminology   
    
    V = sqrt(N)*UP*R^(-1/2);
    W = sqrt(N)*UQ*C^(-1/2);

return;