% EMScorr:  This function analyzes the correlation between environmental variables and correspondence scores.
%
%   USAGE: [r,prob] = EMScorr(X,Y,ax,kind)
%           X = [sites x species] presence-absense data matrix
%           Y = [sites x # of environental variables]vector or matrix of enviornmental variables for sites
%           ax = optional, specifies which axis of correspondance to use in ordination {default = 1) 
%           kind = optional flag indicating modified correlation coefficients:
%                     0 = Pearson product-moment correlation [default]
%                     1 = Spearman rank correlation
%           ------------------------------------------------------------------------------------------------
%           r = [1 x # of environental variables] vector of Spearman rank correlations
%           prob = [1 x # of environental variables] vector of assocaited p-values
%
%   Chris L. Higgins 4/27/2010
%
                      
function [r,prob] = EMScorr(X,Y,ax,kind)

    if(nargin < 3)                                              % Allocate input arguments
        ax = [];
    end;
    if(nargin < 4)
        kind = [];
    end;
    
    if(isempty(ax))
        ax = 1;
    end;
    if(isempty(kind))
        kind = 0;
    end;

    X = allzeros(X);                                            % Remove any rows or columns that contain all zeros
    X = makebinary(X);                                          % Make sure data matrix is binary
    
    [V,W] = CA(X);                                              % Perform correspondence analysis
    [E,ir] = sort(V(ax+1,:));                                   % Sort eigenvectors by row
    
    [r,prob,CI_low,CI_high] = corr(E,Y(ir,:),kind,1000);        % Conduct Spearman rank correlation analysis

     
return;