% Evar: Returns a value of an evenness value as presented in Smith and Wilson (1996).
%
%  USAGE: Ev = Evar(X)
%
%         X = [Sites x Species] abundance matrix
%         -------------------------------------------------------------
%         Ev = [Sites x 1] vector of evenness values
%           
% Chris Higgins 3/22/2011
%
%   Smith, B. and J.B. Wilson. 1996.  A consumer's guide to evenness indices.  Oikos 76:70-82.
%


function Ev = Evar(X)

    [r,c] = size(X);                                        % Determine the number of sites
    if(r > 1 & c == 1)                                      % Convert column vector to row vector
        X = X';
        [r,c] = size(X);
    end;
    
    Ev = zeros(r,1);                                        % Allocate column vector for diversity indices
    for i = 1:r
        ind = find(X(i,:) > 0);                             % Find all non-zero entries
        if(isempty(ind))
            Ev(i) = 0;
        else
            S = length(ind);
            Y = X(i,ind);
            a = 0;
            for j = 1:S
                b = 0;
                for k = 1:S
                    b = b + (log(Y(k))/S);
                end;
                a = a + (log(Y(j)) - b)^2;           
            end;
            Ev(i) = 1 - (2/pi) * atan(a/S);                               
        end;
    end;
  
return; 