% ExpPopGrowth:  This function models exponential population growth. Growth can either be deterministic or stochastic.
%
%   Usage: N = ExpPopGrowth(N0,t,r,rVar,doplot)
%
%   N0 = initial population size
%   t = time or number of generations
%   r = intrinsic rate of increase
%   rVar = optional, specifies whether or not to use determinstic (0) or stochastic (not 0) model  
%   doplot = optional, specifies whether or not to produce figure of expected abundances {default = 0}
%   ---------------------------------------------------------------------------------------------------------------------------
%   N = [1 x t] vector of predicted population sizes at time t
%
%   Chris Higgins 1/22/2008
%

function N = ExpPopGrowth(N0,t,r,rVar,doplot)

    if(nargin < 4)                                  % Allocate input arguments
        rVar = [];
    end;
    if(nargin < 5)
        doplot = [];
    end;
    
    if(isempty(rVar))
        rVar = 0;
    end;
    if(isempty(doplot))
        doplot = 0;
    end;

    for i = 1:t
        rBar = normrnd(r,rVar);                     % Sample a random number from a Normal dist. with a mean of 'r' and a variance of 'rVar'           
        N(i) = N0*exp(rBar*i);
    end;
 
    if(doplot ~= 0)
        plot(N);                                    % Plot expected values
    end;
    
return; 