% ExpPopGrowthFitf:  This is the objective function used to estimate parameters of the exponetial growth model.
%
%   Usage: dev = ExpPopGrowthFitf(param,Obs)
%
%   param = [1 x 1] or [1 x 2] vector of parameters
%   Obs = [1 x t] vector of observed abundances
%   ---------------------------------------------------------------------------------------------------------------------------
%   dev = sum of squared differences between observed and expected values
%
%   Chris Higgins 2/1/2008
%

function dev = ExpPopGrowthFitf(param,Obs)
   
    t = length(Obs);                                            % Determine the length of time involved with the observed abundances
    N0 = Obs(1);                                                % Set the initial population size to the first obeserved value
    
    if(length(param) == 1)                                      % If only 1 parameter is passed, set variance to 0 --- deterministic model
        param(2) = 0;
    end;
        
    for i = 1:t
        rBar = normrnd(param(1),param(2));                      % Sample a random number from a Normal dist. with a mean of 'r' and a variance of 'rVar'           
        Exp(i) = N0*exp(rBar*i);
    end; 
    
    dev = sumsqdev(Obs,Exp);                                    % Calculate sum of squared differences between observed and expected abundances
    
return; 