% ExpPopGrowthFit:  This function models exponential population growth.
%
%   Usage: N = ExpPopGrowthFit(Obs)
%
%   Obs = [1 x t] vector of population sizes over time 
%   ---------------------------------------------------------------------------------------------------------------------------
%   N = [1 x t] vector of predicted population sizes at time t
%
%   Chris Higgins 1/22/2008
%

function [rest,rVarest,Exp] = ExpPopGrowthFit(Obs)

    rest = 0;                                                       % Set initial value of k to zero
    rest = fminsearch('ExpPopGrowthFitr',rest,[],Obs);              % Optimization routine
    
    rVarest = fminbnd('ExpPopGrowthFitrVar',0,rest,[],Obs,rest);
%     rVarest = rest * 0.10;
%     rVarest = fminsearch('ExpPopGrowthFitrVar',rVarest,[],Obs,rest);     

    t = length(Obs);
    N0 = Obs(1);
    
    for i = 1:t
        rBar = normrnd(rest,rVarest);                               % Sample a random number from a Normal dist. with a mean of 'r' and a variance of 'rVar'           
        Exp(i) = N0*exp(rBar*i);
    end;
    
return; 