% FTEST1 : 	Performs an F-Test on the given data
%
%	Usage: 	p_value = ftest1(x,grps,{iter})
%
%				p_value = 	deviations as large or larger due to chance
%								alone in the direction or directions of the
%								alternate hypothesis
%				---------------------------------------------------------
%				x = a data vector
%				grps = a grouping vector
%				iter = the number of iterations {default = 1000}
%
%	Chris Higgins 1/26/2000
%

function p_value = ftest1(x,grps,iter)

   if(nargin < 3)
      iter = [];
   end;
   if(isempty(iter))
      iter = 1000;
   end;
   
   f_hat = fvalue(x,grps);
   f_null = zeros(iter,1);
   f_samp = zeros(iter,1);
   
   for i = 1:iter
      boot_x = bootsamp1(x);
      f_null(i) = fvalue(boot_x,grps);
      
      boot_x = bootsamp1(x,grps);
      f_samp(i) = fvalue(boot_x,grps);
   end;
   
   figure;
   hist(f_null);
   p_value = sum(f_null >= f_hat) ./ iter;
   
   figure;
   hist(f_samp);
   
return;