% HWE:	Hardy-Weinberg Equilibrium: With random mating, the choices of male gamete and
%			female gamete are independent trials, and so pairs of gametes carrying
%			the alleles AA, Aa, or aa are expected in porportions given by the 
%			Hardy-Weinberg principle.
%
%	Usage:	[AA,Aa,aa]= hwe(p,q,{plotflag})
%
%			AA = homozygote geneotypic frequency
%			Aa = heterozygote genotypic frequency
%			aa = homozygote geneotypic frequency
%			-------------------------------------------------------------------------
%			p = the allele frequency
%			q = the allele frequency
%			plotflag = optional, plot variable (1:plot 0:no plot {default = 1})
%
%	Chris Higgins 1/18/2000
%

function [AA,Aa,aa] = hwe(p,q,plotflag)

	if(p < 0)
		error('HWE: The gene frequency can not be less than zero.');
	end;
	if(p > 1)
		error('HWE: The gene frequency can not be greater than one.');
	end;
	if(q < 0)
		error('HWE: The gene frequency can not be less than zero.');
	end;
	if(q > 1)
		error('HWE: The gene frequency can not be greater than one.');
	end;
	if(nargin < 3)
		plotflag = [];
	end;
	if(isempty(plotflag))
		plotflag = 1;
	end;
	
	AA = p^2;
	Aa = 2 .* p .* q;
	aa = q^2;
      
   if(plotflag == 1)
      bar(x);
      v=axis;
      v([3:4])=[0 1];
      axis(v);
      set(gca,'xticklabel',['AA';'Aa';'aa']);
      set(gca,'YTick',[0:0.1:1.0]);
      title('Hardy-Weinberg Equilibrium');
      ylabel('Relative Frequencies');
      xlabel('Genotype');
   end;
return;
