% HWECHI2:	Hardy-Weinberg Equilibrium: With random mating, the choices of male gamete and
%				female gamete are independent trials, and so pairs of gametes carrying
%				the alleles AA, Aa, or aa are expected in porportions given by the 
%				Hardy-Weinberg principle. This function compares the expected values 
%				to the observed values via a chi-square test.
%
%	Usage:	[p_hat,q_hat,p_value] = hwechi2(obs,)
%
%				p_hat = the genotypic frequency for the dominant allele
%				q_hat = the genotypic frequency for the recessive allele
%				p_value = the p-value for the chi-square test
%				--------------------------------------------------------
%				obs = a vector containing the observed genotypes [AA Aa aa]
%
%	Chris Higgins 1/28/2000
%

function [p_hat,q_hat,p_value] = hwechi2(obs)
	tot = sum(obs);
   p_AA = obs(1) ./ tot;
   p_Aa = obs(2) ./ tot;
   p_aa = obs(3) ./ tot;
   p_hat = p_AA + (p_Aa ./ 2);				% Allele frequencies
   q_hat = p_aa + (p_Aa ./ 2);
   chi = zeros(3,1);
   exp = [p_hat^2 2.*p_hat.*q_hat q_hat^2].* tot;  
   chi = ((obs-exp).^2) ./ exp;
   chi2 = sum(chi);
   
   p_value = 1-chi2cdf(chi2,1);
return;