%LOGROWTH:	Detremines the population size based on the logistics growth equation
%				given the birth and death rates, the initial population size, and the 
%				length of time.
%
%	USAGE: 	[k,dN,gen] = logrowth(B0,D0,N0,b,d,max_gen,noiseB,noiseD)
%		
%      		k = 			the carrying capacity
%				dN = the maximum value for the change in size
%				gen = 		the number of generations required to get the max_delta_N
%				----------------------------------------------------------------
%				B0 = 			the initial birth rate
%				D0 = 			the initial death rate
%				N0 = 			the initial population size
%				b = 			the birth rate as a function of population size
%				d = 			the death rate as a function of population size
%				max_gen = 	the maximum number of generations projected 
%				noiseB = 	random variation caused by noise in births
%				noiseD = 	random variation caused by noise in deaths
%
% Chris Higgins 11/15/1999
%

function [k,dN,gen] = logrowth(B0,D0,N0,b,d,max_gen,noiseB,noiseD)
	if(B0 < 0)
      error('LOGISTIC: The initial birth rate must be positive.');
   end;
   if(D0 < 0)
      error('LOGISTIC: The initial death rate must be positive.');
   end;
   if(N0 < 0)
      error('LOGISTIC: The initial population size must be positive.');
   end;
   if(b < 0)
      error('LOGISTIC: The birth rate must be positive.');
   end;
   if(d < 0)
      error('LOGISTIC: The death rate must be poositive.');
   end;
   if(max_gen < 0)
      error('LOGISTIC: The length of time must be positive.');
   end;
   if(nargin < 7)
      noiseB = 0;
   end;
   if(nargin < 8)
      noiseD = 0;
   end;
   N = zeros((max_gen + 1),1);
   N(1) = N0;
   delta_N = zeros((max_gen + 1),1);
   delta_N = nan;
   for i = 2:(max_gen + 1)
      Bi = B0 - (b .* N(i - 1)) + (randn .* noiseB);
      Di = D0 + (d .* N(i - 1)) + (randn .* noiseD);
      N(i) = (Bi .* N(i - 1)) + ((1-Di) .* N(i - 1));
      delta_N(i) = N(i) - N(i - 1);
   end;
   k = (B0 - D0) ./ (b + d);
   [max_delta_N,i] = max(delta_N);
   gen = i - 1;
   
   figure;
   plot([1:(max_gen + 1)],N);
   figure;
   plot([1:(max_gen + 1)],delta_N);
 return;


  