%LOTKAVOL: 	Accepts values for two species and plots the sizes of the two populations
%           on the same graph,as a function of time. It also plots the sizes of the
%           two populations versus one another,as a trajectory.(N1 on the x axis and
%           N2 on the y axis)
%
%   USAGE 	[gens1,gens2] = lotkavol(N1,N2,r1,r2,K1,K2,{alpha12},{alpha21})
%         
%           gens1 = the number of generations for species 1
%           gens2 = the number of generations for species 2
% 
%           ------------------------------------------------------------------------
%           N1 = the population size for species 1
%           N2 = the population size for species 2
%           r1 = the instantaneous rate of increase for species 1
%           r2 = the instantaneous rate of increase for species 2
%           K1 = the carrying capacity for species 1
%           K2 = the carrying capacity for species 2
%           alpha12 = optional, competition coefficient for species 1; {default = 0}
%           alpha21 = optional, competition coefficient for species 2; {default = 0}
%           
% Chris Higgins 11/22/1999
%

function gens = lotkavol(N1,N2,r1,r2,K1,K2,alpha12,alpha21)

  if(nargin < 7)
     alpha12 = [];
  end;
  if(nargin < 8)
     aplha21 = [];
  end;
  
  if(isempty(alpha12))
     alpha12 = 0;
  end;
  if(isempty(alpha21))
     alpha21 = 0;
  end;
  
  if(N1 < 0)
     error('LOTKAVOL: The population size for species 1 must be greater than zero.');
  end;
  if(N2 < 0)
     error('LOTKAVOL: The population size for species 2 must be greater than zero.');
  end;
 
  gens = 0;
  dN1 = N1;
  dN2 = N2;
  delta_N1 = [];
  delta_N1(1) = N1;
  delta_N2 = [];
  delta_N2(1) = N2;
  
  while(dN1 < K1 & dN1 > 0.0001 & dN2 < K2 & dN2 > 0.0001)
     gens = gens + 1;
     c1 = alpha12 .* dN2;
     c2 = alpha21 .* dN1;
     num1 = r1 .* dN1 .* (K1 - N1 - c1);
     num2 = r2 .* dN2 .* (K2 - N2 - c2);
     dN1 = floor(num1 ./ K1);
     dN2 = floor(num2 ./ K2);
     delta_N1 = [delta_N1;dN1]; 
     delta_N2 = [delta_N2;dN2];
  end;

  figure;
  plot(delta_N1,'r');
  hold;
  plot(delta_N2,'b');
  
  figure;
  plot(delta_N1,delta_N2);
  return;
  
  