%LOADRANK;	Ranks the loadings from a discriminant function analysis as a weighted average
%				of the loadings with the percent of the total variance.
%
% 	USAGE:	[rank, value] = 	loadrank(load,per,{num})
%
%				rank = 	a vector containg the rankings of the loadings
%				value = 	a vector containg the numeric value of the weighted average
%				----------------------------------------------------------------------------
%				load = 	the loadings from a discriminant function analysis
%				per = 	a vector containing the percent of the total variance from a dfa
%				num = 	optional, the number of discriminant functions to include
%
%	Chris Higgins 7/11/2000
%
%	Stand Alone

function [rank,value] = loadrank(load,per,num)

	[r,c] = size(load);

	if(nargin < 1)
      error('LOADRANK: The loading matrix must be included.');
   end;
   if(nargin < 2)
      error('LOADRANK: The vector of perentage smust be included.');
   end;
   if(nargin < 3)
      num = [];
   end;
   
   if(isempty(num))
      num = c;
   end;
   
	if(any(per > 1))
   	per = per ./ 100;
	end;

	l = abs(load(:,1:num));
	p = per(1:num);

	w = l * p;

	[v,ind] = sort(-1 * w);
	value = abs(v);
   
   rank(:,1) = ind;
   rank(:,2) = value;
return

