% LogPopGrowthFit: This function estimates the parameters in the Logistic growth model, given a series of observed values. 
%   It uses the Exponential growth model to estimate the intrinisic rate of increase (mean and variance), then fits the 
%   carrying capacity using the logistic formula.
%
%   Usage:
%
%   Obs = a vector of observed abundances over time
%   ----------------------------------------------------------------------------------------------------------------------
%   Exp = a vector of expected abundances based on Logistic growth
%   

function [Exp,param] = LogPopGrowthFit(Obs)

    t = length(Obs);
    
    ExpParam = ExpPopGrowthFit(Obs);

    param = [max(Obs) max(Obs)*.1];
    param = fminsearch('LogPopGrowthFitf',param,[],Obs,ExpParam(1),ExpParam(2)); 
 
%     r = param(1);
%     rVar = param(2);
    K = param(1);
    KVar = param(2);
    
    Exp(1) = Obs(1);
    
    for i = 1:t-1
        rBar = normrnd(ExpParam(1),ExpParam(2));
        KBar = normrnd(K,KVar);
        Exp(i+1) = Exp(i)*exp(rBar*(1-(Exp(i)/KBar)));
    end;
    
    
return;