% MDBmetric: Calculates the integrated multiple dimensions of biodiversity metric of Scheiner 2012, including
%   a single metric that combines taxonomic, functional, and phylogenetic biodiversity as well as
%   individual components for each dimension.
%
%   Usage: [a,b,c,d,e...] = MDBmetric(X,Y,Z)
%
%       X = [Sites x Species] abundance matrix
%       Y =
%       Z = 
%       --------------------------------------------------------------------------------------------------------------------------------
%       a = 
%       b = 
%       c = 
%       d = 
%       e = 
%       
%
%   Steven J. Presley 12/01/12
%

function [a,b,c,d,e,...] = MDBmetric(X,Y,Z)

%error checking
    if(nargin < 2)
        TotSAD = [];
    end;
    
    
    S = ;                                   % number of species 
    R = ;                                   % richness = number of objects in a set
    E = ;                                   % evenness = extent to which species in a sample have the same abundance, phylogenetic divergence or functional distinctiveness
    
    
    n[i] = ;                                % abundance of the ith species
    N = sum(n);                             % total abundance of all species
    p[i] = n[i]/N;                          % proportional abundance of the ith species
    
    
    q = ;                                   % exponent that determines how relative proportions are weighed
    
    
    L[j] = ;                                % length (divergence) of the jth branch of the cladogram
    s[j] = ;                                % number of species that share the jth branch
    T = ;                                   % total duration of the cladogram
    L[i,j] = L[j]/s[j];                     % proportional length of the jth branch of the ith species
    L[i] = sum(L[i,j]);                     % lineage divergence the ith species
    L = sum(L[i]);                          % total lineage divergence of all species
    l[i] = L[i]/L;                          % proportional lineage divergence of the ith species
    
    
    m = ;                                   % number of traits (dimensions) that define ecological functional space
    s[i,k] = ;                              % standardized functional value of the kth trait of the ith species
    
    d[i,j] = sqrt(sum(s[i,k]-s[j,k]^2));    % functional distance between the ith and jth species  ***will have to write out****
    d[i] = min(X);                          % smallest functional distance between the ith species and all other species
    Cm = (pi^(m/2))/(gamma(m/2 + 1));       % coefficient for the volume of a m-dimensional hypersphere
    vi = C[m]* d[i];                        % functional volume of the ith species
    V = sum(v[i]);                          % total functional volume of all species
    f[i] = v[i]/V;                          % proportional functional volume of the ith species
    e[i] = ;                                % contribution to a specified ecosystem function of the ith species
    E = sum(e[i]);                          % total ecosystem function of all species
    f[i] = e[i]/E;                          % proportional functional contribution of the ith species
    
    
    DA = (sum(p[i]^q))^(1/(1-q);            % for i = 1:s; abundance diversity, the effective number of equally abundant species
    DP = (sum(l[i]^q))^(1/(1-q);            % phylogenetic diversity, the effective number of equally divergent species
    DF = (sum(f[i]^q))^(1/(1-q);            % functional diversity, the effective number of equally distinct species
    
    
    
    
    
   

return;