%MINPATH: 	Determines the minimum path length and the number of paths from v1
%				to v2 that correspond to the adjacency matrix.
%
%	USAGE:	[path_length,num_paths] = minpath(A,v1,v2)
%
%				path_length = the minimum path length from v1 to v2
%				num_paths = the number of paths of minimum length
%				-----------------------------------------------------
%				A = a input adjacency matrix that is square and binary and diagonals = 0
%				v1 = the vertex we are measuring from
%				v2 = the vertex we are measuring to
%
% Chris Higgins 11/18/1999
%

function [path_length,num_paths] = minpath(A,v1,v2)
	[r,c] = size(A);
   if(r ~= c)
      error('MINPATH: The adjacency matrix must be square.');
   end;
   if(sum(diag(A)) ~= 0)
      error('MINPATH: The diagonal of the adajecency matrix must be zeros.');
   end;
   grps = sort(unique1(A));
   if(~(grps == 0 |grps == 1| grps == [0;1]))
      error('MINPATH: The adajecency matrix must be binary.');
   end;
   if((v1 - floor(v1)) ~= 0)
      error('MINPATH: The "from" vertex must be an integer.');
   end;
   if((v2 - floor(v2)) ~= 0)
      error('MINPATH: The "to" vertex must be an integer.');
   end;
   if(v1 > r)
      error('MINPATH: The "from" vertex must be less than the number of rows of A.');
   end;
   if(v2 > r)
      error('MINPATH: The "to" vertex must be less than the number of rows of A.');
   end;
   exp = 1;
	path_length = 0; 
   while(path_length == 0 & exp <= r)
      B = A^exp;
      if(B(v1,v2) ~= 0)
	      	path_length = exp;
   	   	num_paths = B(v1,v2);
      end;
      exp= exp +1;
   end;
  return;

      
      
  
   
