% MOMSTATS:   A function that will accept a vector of values from a data matrix
%             and will return the mean, variance, skewness, and kurtosis.
%
%     Usage:  [m, v, skew, kurt] = momstats(x)
%
%             m = mean of x
%             v = variance of x
%             skew = skewness of x
%             kurt = kurtosis of x
%             --------------------------------------------
%             x = a data matrix
%
% Chris Higgins 10/21/1999
%

function [m,v,skew,kurt] = momstats(x)

    x = x(:);
    m = mean(x);
    v = var(x);
    n = length(x);
    s = std(x);
  
    diff3 = [];
    for i = 1:n                                         % Determines a vector of the
        d = (x(i) - m);                                  % difference cubed
        d3 = (d^3);
        diff3 = [diff3;d3];
    end;
    dsum = sum(diff3);                                  % Sums the cubed differences
    skew = (n .* (dsum))/((n-1) .* (n-2) .* (s^3));     % Formula for skewness
  
    diff4 = [];
    diff2 = [];
    for i = 1:n                                         % Determines two vectors of the
        d1 = (x(i) - m);                                 % differences (one is to the 4th
        d4 = (d1^4);                                     % power and the other is squared)
        diff4 = [diff4;d4];
        d2 = (d1^2);
        diff2 = [diff2;d2];
    end;
    dsum1 = sum(diff4);                                 % Sums the quad differences
    dsum2 = sum(diff2);                                 % Sums the squared differernces
    kurtn = ((n.*(n+1)/(n-1)).*(dsum1)-3.*(dsum2^2));   % Numerator for the formula 
    kurtd = ((n-2).*(n-3).*(s^4));                      % Denominator for the formula
    kurt = (kurtn/kurtd) + 3;                           % Formula for kurtosis 
  
return
  
  
     
    