% MakeRelative: Converts a matrix, or vector, of absolute values into a matrix, or vector, of relative values.
%
%   Usage: Y = MakeRelative(X,byrow)
%
%   X = absolute matrix or vector
%   byrow = specifies whether or not to sum by rows (default == 1) or columns (0)
%   -------------------------------------------------------------------------------------------------------
%   Y = relative matrix or vector
%
%   Chris L. Higgins 4/16/2007
%

function Y = MakeRelative(X,byrow)

    if(nargin < 2)
        byrow = [];
    end;
    
    if(isempty(byrow))
        byrow = 1;
    end;
    
    [r,c] = size(X);                            % Determine size of input matrix, or vector
    
    b = isvector(X);
    if(b == 1)
        Y = X / sum(X);
    else;    
        if(byrow == 1)
            for i = 1:r
                Y(i,:) = X(i,:) / sum(X(i,:));
            end;
        else
            for i = 1:c
                Y(:,i) = X(:,i) / sum(X(:,i));
            end;
        end;
    end;
      
return;