%NNETPATH:	Neural network for searchs paths produced by different search 
%				tactics.
%
%
%

function [E,Corr,a2,W1,b1,W2,b2,W3,b3] = nnetpath(rdata,grps,n,hidlayers,nodes,epochs,iter)

	if(nargin < 1)
      error('NNETPATH: The training data must be supplied.');
   end;
   if(nargin < 2)
      error('NNETPATH: The grouping vector for the training data must be supplied');
   end;
   if(nargin < 3)
      n = [];
   end;
   if(nargin < 4)
      hidlayers = [];
   end;
   if(nargin < 5)
      nodes =[];
   end;
   if(nargin < 6)
      epochs = [];
   end;
   if(nargin < 7)
      iter = [];
   end;
   
   if(isempty(n))
      n=100;
   end;
   if(isempty(hidlayers))
      hidlayers = 1;
   end;
   if(isempty(nodes))
      nodes = [2 2];
   end;
   if(isempty(epochs))
      epochs = 25000;
   end;
   if(isempty(iter))
      iter = 1;
   end;
   
   [r,c] = size(rdata);
   [u,freq] = unique1(grps);

   ind = (ceil(rand(n,1) .* freq(1))); 
   ind1 = ind + (0 .* freq(1));
   ind2 = ind + (1 .* freq(1));
   ind3 = ind + (2.5 .* freq(1));
   ind4 = ind + (4 .* freq(1));
   ind5 = ind + (5.5 .* freq(1));
   
   P1 = (rdata(ind1,:))';						% Randomly pull n from data
   P2 = (rdata(ind2,:))';						% Randomly pull n from data
   P3 = (rdata(ind3,:))';
   P4 = (rdata(ind4,:))';
   P5 = (rdata(ind5,:))';
   P = [P1 P2 P3 P4 P5];									% Combine data from both tactics
  
   indt = (ceil(rand(n,1) .* freq(1))); 	% Generate random indiceis for test data
   indt1 = indt + (0 .* freq(1));			% From MINI
   indt2 = indt + (1 .* freq(1));			% From NEAR
   indt3 = indt + (2.5 .* freq(1));			% From RECI & INVE
   indt4 = indt + (4 .* freq(1));			% From TRAJ
   indt5 = indt + (5.5 .* freq(1));			% From PEAR & LEVY
   
   test1 = (rdata(indt1,:))';					% Geneate random test data
   test2 = (rdata(indt2,:))';
   test3 = (rdata(indt3,:))';
   test4 = (rdata(indt4,:))';
   test5 = (rdata(indt5,:))';
   test = [test1 test2 test3 test4 test5];
   
   T1 = (makegrps([1 0 0 0 0],n))';				% Generate target matrix of 
   T2 = (makegrps([0 1 0 0 0],n))';				%   proper size for output
   T3 = (makegrps([0 0 1 0 0],n))';
   T4 = (makegrps([0 0 0 1 0],n))';
   T5 = (makegrps([0 0 0 0 1],n))';
   T = [T1;T2;T3;T4;T5];                  

   tp = [1000 epochs 0.1];					% Allocate tp vector for training
   
   E = [];
	Corr = [];   
   
   for g = 1:iter
      for i = nodes(1):2:nodes(2)
         for j = nodes(1):2:nodes(2)
            if(hidlayers == 1)
               [W1,b1,W2,b2] = initff(P,i,'tansig',T,'logsig');
					[W1,b1,W2,b2,ep,err] = trainbpx(W1,b1,'tansig',W2,b2,'logsig',P,T,tp);
          		a2 = simuff(test,W1,b1,'tansig',W2,b2,'logsig');         	   
            end;
            if(hidlayers == 2)
               [W1,b1,W2,b2,W3,b3] = initff(P,i,'tansig',j,'logsig',T,'logsig');
               [W1,b1,W2,b2,W3,b3,ep,err] = trainbpx(W1,b1,'tansig',W2,b2,'logsig',W3,b3,'logsig',P,T,tp);
					a2 = simuff(test,W1,b1,'tansig',W2,b2,'logsig',W3,b3,'logsig');
            end;
         	[r1,c1]=size(err); 
         	e = err(1,c1);
         	E = [E;e];
            
            C1 = 0;
            C2 = 0;
            C3 = 0;
            C4 = 0;
            C5 = 0;
            
            for k = 1:n
   			   if(a2(1,k)>0.5 & a2(2,k)<0.5 & a2(3,k)<0.5 & a2(4,k)<0.5 & a2(5,k)<0.5)
      	   	   C1 = C1 + 1;
	            end;
   	      end;
      	   for k = (n+1):(2.*n)
  			  		if(a2(1,k)<0.5 & a2(2,k)>0.5 & a2(3,k)<0.5 & a2(4,k)<0.5 & a2(5,k)<0.5)
      	   	   C2 = C2 + 1;
	            end;
            end;
      	   for k = (2.*n+1):(3.*n)
  			  		if(a2(1,k)<0.5 & a2(2,k)<0.5 & a2(3,k)>0.5 & a2(4,k)<0.5 & a2(5,k)<0.5)
      	   	   C3 = C3 + 1;
	            end;
            end;
       	   for k = (3.*n+1):(4.*n)
  			  		if(a2(1,k)<0.5 & a2(2,k)<0.5 & a2(3,k)<0.5 & a2(4,k)>0.5 & a2(5,k)<0.5)
      	   	   C4 = C4 + 1;
	            end;
            end;
      	   for k = (4.*n+1):(5.*n)
  			  		if(a2(1,k)<0.5 & a2(2,k)<0.5 & a2(3,k)<0.5 & a2(4,k)<0.5 & a2(5,k)>0.5)
      	   	   C5 = C5 + 1;
	            end;
            end;            
      
            CC = [C1 C2 C3 C4 C5] ./ n;
            CC1 = [g i j CC]
   	      Corr = [Corr;CC1];
         end;
	   end;
   end;
return