% NestUp:  This function calculates the number of unexpected presences, its standardized versions, and corresponding significance values.
%
%   Usage: [Up,PUp,PvUp,zUp,MUp,SUp] = NestUp(X,ord,model,iter,ax)
%
%       X = [sites x species] binary data matrix
%       ord = {optional}, specifies how to ordinate the data matrix
%           0 = no ordination is performed 
%           1 = reciprical averaging
%           2 = maximally packed as in nestedness calcualtor
%           3 = species richness and occurence totals {default}
%       model = optional, specifies which null model to use
%           1 = Species richness per site is equiprobable and species occurrence is equiprobable (RANDOM00 - Temperature)
%           2 = Species richness per site is equiprobable and species occurrence is fixed 
%           3 = Species richness per site is fixed & species occurrence is equiprobable (RANDOM0)
%           4 = Species richness per site is proportional & species occurrence is fixed
%           5 = Species richness per site is fixed & species occurrence is proportional (RANDOM1) --- {default}
%           6 = Species richness per site is proportional & species occurrence is equiprobable
%           7 = Species richness per site is equiprobable & species occurrence is proportional
%           8 = Species richness per site is proportional & species occurrence is proportional
%           9 = Species richness per site is fixed & species occurrence is fixed
%           10 = RANDNEST null model (Jonsson 2001) that relaxes contraints of percent fill and fixed row totals
%       iter = optional, specifies how many iterations to run (deafult = 0}
%       ax = optional, specifies which axis of correspondance to use in ordination {default = 1)
%       --------------------------------------------------------------------------------------------------------------
%       Up = the number of unexpected presences
%       PUp = standardized version of Up in percent nestedness (ranges from 0 to 100)
%       PvUp = significance of Up based on z distribution
%       zUp = standardized z-score
%       MUp = mean of randomized values
%       SUp = standard deviation of randomized values
%
%   Chris L. Higgins 4/2/2008
%
%   Cutler, A.  1991.  Nested faunas and extinction in fragmented habitats.  Conservation Biology, 5(4): 496-505.
%

function [Up,PUp,PvUp,zUp,MUp,SUp] = NestUp(X,ord,model,iter,ax)

    if(nargin < 2)                                      % Allocate input arguments
        ord = [];
    end;
    if(nargin < 3)
        model = [];
    end;
    if(nargin < 4)
        iter = [];
    end;
    if(nargin < 5)
        ax = [];
    end;
    
    if(isempty(ord))
        ord = 3;
    end;
    if(isempty(model))
        model = 5;
    end;
    if(isempty(iter))
        iter = 0;
    end;
    if(isempty(ax))
        ax = 1;
    end;

% Use the objective fucntion and pull out needed values
    [Ua,Up,Ut,PUa,PUp,PUt,PvUa,PvUp,PvUt,zUa,zUp,zUt,MUa,MUp,MUt,SUa,SUp,SUt] = NestU(X,ord,model,iter,ax);
    
return;