%PATHITER: 	Determines the number of observations per group it takes to make the 
%				maximum p-vaule between all possible pairwise manovas to reach significance
%				at any give alpha level
%
%	USAGE:	[obs,max_p] = pathiter({alpha},{inc},{max})
%
%				obs =		the number of observations per group
%				max_p = 	the maximum p-value after significance
%				------------------------------------------------------------
%				alpha = 	optional, the alpha error (default = 0.01}
%				inc = 	optional, the increment increase in observations {default = 50}
%				max = 	optional, the maximum number of iterations {default = 10000}
%
%	Chris Higgins 5/24/2000
%
%	REQUIRES: pathdatasame, manovapair

function [obs,max_p] = pathiter(alpha,inc,max)

	if(nargin < 1)
      alpha = [];
   end;
   if(nargin < 2)
      inc = [];
   end;
   if(nargin < 3)
      max = [];
   end;
   
   if(isempty(alpha))
      alpha = 0.01;
   end;
   if(isempty(inc))
      inc = 50;
   end;
   if(isempty(max))
      max = 10000;
   end;
   
   maxp = 1;
   a = 0;
   
	while(maxp > alpha)
      a = a + 1;
      ngrp = a * inc;
      [data,grps] = pathdatasame(ngrp);
      max_p = manovapair(data,grps);
   end;
   
   obs = ngrp;
return;
   