% PCANALYSIS: Preforms a principal component analysis on a data matrix.
%
%	USAGE: [eigvals,per_var,ci_vals,load,ci_load,eigvects,ci_vect,PC]
%				= pcanalysis(x,{iter},{co})
%
%				eigvals = a [p x 1]column vector containing the eigenvalues
%				per_var = a [p x 1]column vector containing the percent
%					variance accounted for by the corresponding eigenvalues
%				ci_vals = a [p x 2]matrix containing the confidence limits
%					of the eigenvalues
%						column 1 = the lower limit
%						column 2 = the upper limit
%				load = a [p x p] matrix containing the vector correlations
%				ci_load = a [p^p x 2] matrix containing the confidence
%					limits of the loadings
%						column 1 = the lower limit
%						column 2 = the upper limit
%				eigvects = a [p x p] matrix containing the eigenvectors
%				ci_vect = a [p^p x 2] matrix containing the confidence
%					limits for the eigenvectors
%						column 1 = the lower limit
%						column 2 = the upper limit
%				PC = a [n x p] matrix of principal component scores
%				----------------------------------------------------------
%				x  = 	a [n x p] data matrix
%				iter = the number of iterations {default = 0}
%				co = 	a variable to determine if we use the covariance 
%					matrix or the correlation matrix
%						0 = covariance matrix {default}
%						1 = correlation matrix
%
%	Chris Higgins 4/27/2000
%

function [eigvals,per_var,ci_vals,load,ci_load,eigvects,ci_vect,PC]...
    = pcanalysis(x,iter,co)

	[r,c] = size(x);

	if(nargin < 2)
     	iter = [];
   end;
   if(nargin < 3)
      co = [];
   end;
    
   if(isempty(iter))
      iter = 0;
   end;
   if(isempty(c))
      co = 0;
   end;
     
   [eigvects,eigvals] = eiganalysis(x,co)
    
   len1 = length(eigvects)^2;
   len2 = length(eigvals);
      
   per_var = (eigvals ./ sum(eigvals)) * 100;
   PC = x * eigvects;
   load = corr(x,PC);
   
   if(iter ~= 0)
  		beigvects = zeros(iter,len1);
      beigvals = zeros(iter,len2);
      loadings = zeros(iter,len1);  
		for i = 1:iter
   		bx = bootstrap(x);
      	[vects,vals] = eiganalysis(bx,co);
	      beigvects(i,:) = vects(:)';
         beigvals(i,:) = vals(:)';
         PC = x * eigvects;
         loads = corr(bx,PC);
         loadings(i,:) = loads(:)';
      end;
      ci_vect = zeros(len1,2);
      ci_vals = zeros(len2,2);
      for j = 1:len1
         [lower,upper] = conflimit(beigvects(:,j));
         ci_vect(j,:) = [lower upper];
         [lower,upper] = conflimit(loadings(:,j));
         ci_load(j,:) = [lower upper];
      end;
      for k =1:len2
         [lower,upper] = conflimit(beigvals(:,k));
         ci_vals(k,:) = [lower upper];
      end;
   end;
   
return;
