%PLOTPATH: Plots the path with square axes and vertices if indicated.
%
%	USAGE:	plotpath(pts,sn,{start},{vertex},{font})
%   
%   			-----------------------------------------------------------
%				pts =  an [n x 2] matrix of path coordinates.
%					column 1 = x coordinates
%					column 2 = y coordinates	
%				sn = the starting point index
%				start = optional, boolean - plots start pt as a different symbol {default = 0}
%				vertex = optional, boolean - plots the vertices of the path {default = 0} 
%				font = optional, font size {default = 16}
%
% Chris Higgins	3/21/2000
%  
%	REQUIRES: 	distmatrix, pathrand, pathmax, pathmin, pathnear, pathrecip, pathinvsq
%					paththeta, pathtraj, pathpearson, pathlevy
%

function plotpath(pts,sn,start,vertex,font)

	if(nargin < 3)
      start = [];
   end;
	if(nargin < 4) 
      vertex = [];
   end;
   if(nargin < 5)
      font = [];
   end;
      
   if(isempty(start))
      start = 0;
   end;
   if(isempty(vertex))
      vertex = 0;
   end;
   if(isempty(font))
      font = 16;
   end;
   
   dist = distmatrix(pts);
   
   p = [1:7];
   n = length(p);
   
   for i = p
   
   switch i
     	case 1
   		minpath = pathmin(dist,sn);
   		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
         plot(pts(minpath,1),pts(minpath,2)); 
         hold on;
         if(vertex ~= 0)
         	plot(pts(:,1),pts(:,2),'.');
	      end; 
         if(start ~= 0)
            plot(pts(sn,1),pts(sn,2),'k*');
         end;
         axis([0 50 0 50]);
         axis('square');
         axis off;
         puttitle('MINI',font);
      case 2
   		nearpath = pathnear(pts,sn);
   		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
         plot(pts(nearpath,1),pts(nearpath,2)); 
         hold on;
         if(vertex ~= 0)
         	plot(pts(:,1),pts(:,2),'.');
	      end; 
         if(start ~= 0)
            plot(pts(sn,1),pts(sn,2),'k*');
         end;
         axis([0 50 0 50]);
         axis('square');
         axis off;
         puttitle('NEAR',font);
      case 3
   		recipath = pathreci1(pts,sn);
   		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
         plot(pts(recipath,1),pts(recipath,2)); 
         hold on;
         if(vertex ~= 0)
         	plot(pts(:,1),pts(:,2),'.');
	      end; 
         if(start ~= 0)
            plot(pts(sn,1),pts(sn,2),'k*');
         end;
         axis([0 50 0 50]);
         axis('square');
         axis off;
         puttitle('RECI',font);
 		case 4
    		invepath = pathinve1(pts,sn);
   		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
         plot(pts(invepath,1),pts(invepath,2)); 
         hold on;
         if(vertex ~= 0)
         	plot(pts(:,1),pts(:,2),'.');
	      end; 
         if(start ~= 0)
            plot(pts(sn,1),pts(sn,2),'k*');
         end;
         axis([0 50 0 50]);
         axis('square');
         axis off;
         puttitle('INVE',font);
  		case 5   
   		trajpath = pathtraj(pts);
   		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
         plot(pts(trajpath,1),pts(trajpath,2)); 
         hold on;
         if(vertex ~= 0)
         	plot(pts(:,1),pts(:,2),'.');
	      end; 
         if(start ~= 0)
            plot(pts(sn,1),pts(sn,2),'k*');
         end;
         axis([0 50 0 50]);
         axis('square');
         axis off;
         puttitle('TRAJ',font);
%    case 6
%   		pearpath = pathpear(pts);
%   		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
%         plot(pts(pearpath,1),pts(pearpath,2)); 
%        hold on;
%         if(vertex ~= 0)
%         	plot(pts(:,1),pts(:,2),'.');
%	      end; 
%         if(start ~= 0)
%            plot(pts(sn,1),pts(sn,2),'k*');
%         end;
%         axis([0 50 0 50]);
%         axis('square');
%         axis off;
%         puttitle('Pearson Random Walk',font);
% case 7
%   		levypath = pathlevy(pts);
%  		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
%         plot(pts(levypath,1),pts(levypath,2)); 
%        hold on;
%         if(vertex ~= 0)
 %        	plot(pts(:,1),pts(:,2),'.');
 %	      end; 
%         if(start ~= 0)
%            plot(pts(sn,1),pts(sn,2),'k*');
%         end;
%         axis([0 50 0 50]);
%         axis('square');
%         axis off;
%         puttitle('Levy Random Walk',font);
      case 6
   		randpath = pathrand(pts,sn);
   		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
         plot(pts(randpath,1),pts(randpath,2)); 
         hold on;
         if(vertex ~= 0)
         	plot(pts(:,1),pts(:,2),'.');
	      end; 
         if(start ~= 0)
            plot(pts(sn,1),pts(sn,2),'k*');
         end;
         axis([0 50 0 50]);
         axis('square');
         axis off; 
         puttitle('RAND',font);
      case 7
   		maxpath = pathmax(dist,sn);
   		subplot(ceil(sqrt(n)),ceil(sqrt(n)),i);
         plot(pts(maxpath,1),pts(maxpath,2)); 
         hold on;
         if(vertex ~= 0)
         	plot(pts(:,1),pts(:,2),'.');
	      end; 
         if(start ~= 0)
            plot(pts(sn,1),pts(sn,2),'k*');
         end;
         axis([0 50 0 50]);
         axis('square');
         axis off;
         puttitle('MAXI',font);
      end;
   end;
return;
   