%PATHNEAR: 	Determines the nearest neighbor path generated from a 
%				starting index and a series of coordinates. 
%				
%	Usage: 	nearpath = pathnear(pts,sn)
%				
%				nearpath = the indices for the nearest neighbor path
%				----------------------------------------------------------
%				pts = a [n x 2] matrix of point coordinates
%				sn = the index of a start point within the given set a points
%
%	Chris Higgins 2/7/2000
%
%	Requires: eucl (Strauss)
%

function nearpath = pathnear(pts,sn)

	dist = eucl(pts);									% Generate distance matrix
	len = length(dist);									% Allocate matrices
   
    nearpath = zeros(1,len);
 
 	for i = 1:len										
        dist(i,i)= nan;									% Generate NaN for diagonal
    end;
   
    nearpath(1) = sn;									% Add start point to path   
    dist(sn,:)=[nan];  									% Remove start point from distance matrix
   
    g = min(dist(:,sn));								% Determine minimum distance from start
    ind = find(dist(:,sn) == g);				        % Find food item with that distance
    dist(ind,:)= [nan];									% Remove food item from distance matrix
    nearpath(2) = ind;									% Add closest food item to path
   
    for k = 3:len
   	    g = min(dist(:,ind));						    % Determine minimum distance from point
   	    ind = find(dist(:,ind) == g);		            % Find food item with that distance
        dist(ind,:) = [nan];						    % Remove food item from distance matrix
        nearpath(k) = ind;								% Add closest food item to path
    end;

return;
   
   
