%PATHRECI: 	Determines the reciprocal-distance path generated from a starting point
%				and a series of coordiates.
%
%	USAGE:	recipath = pathreci(pts,sn)
%
%				recipath = the indices for the reciprocal-disance path
%				----------------------------------------------------------------------
%				pts = a [n x 2] matrix of point coordinates
%				sn = the index of a start point within the given set a points
%
%	Chris Higgins 3/11/2000
%
%	Requires: eucl (Strauss)
%

function recipath = pathreci(pts,sn)

	dist = eucl(pts);								% Generate distance matrix
	len = length(dist);									% Determine the number of food items
   
   for i = 1:len
       dist(i,i)= nan;									% Make the diagonal all NaN
   end;
   
   recipath = zeros(1,len);							% Allocate reciprocal distance path
   P = zeros(len,len);
   
   recipdist = 1 ./ dist;								% Calculate all reciprocal distances
   R = recipdist;
   
   for i = 1:len
       R(i,i)= 0;									% Make the diagonal all NaN
   end;
   
   s = sum(R(:,sn));
   y = R(:,sn) ./ s;
   x = cpdf(y);
   ind = find(x > rand);
   r = min(ind);
   
   R(sn,:) = 0; 							% Remove start point from recip matrix
   recipath(1) = sn;									% Add start point to path  
   
   for j = 2:len
        s = sum(R(:,r));
        y = R(:,r) ./ s;
        x = cpdf(y);
        ind = find(x > rand);
        r = min(ind);
        
        R(r,:) = 0; 							
        recipath(j) = r;
    end;
    
   return;