% PLOTLAND: Plots the landmarks and helping points as well as the corresponding distances.
%           
%     Usage: plotland(crds,specs
%
%           crds = the [n x 2] matrix of point coordinates
%           specs = 

function plotland(crds,specs,ifscale,values)
hold on;
   [r,c] = size(crds);
   [rs,cs] = size(specs);
   [u,f] = unique1(specs(:,1));
   
    if(nargin < 3)
        ifscale = [];
    end;
   if(nargin < 4)
      values = [];
   end;
   
   lenu = length(u);
   
   landmarks = [];
   help_pts = [];
   a = [];
   b = [];
   midpts = zeros(lenu,2);
   
   for i = 1:lenu                                                          % Determine which coordinate and landmarks 
      ind = find(specs(:,1) == i);                                         %     or helping points
      leni = length(ind);
      for j = 1:leni
         a = [a;specs(ind(j),2);specs(ind(j),3)];
         b = [b;specs(ind(j),2) specs(ind(j),3)];
      end;
      lena = length(a);
      landmarks = [landmarks;a(1);a(lena)];
      if(leni > 1)
         for j = 2:lena - 1
            help_pts = [help_pts;a(j)];
         end;
      end;
      a = [];
      len = pathlen(b);
      
      ij = specs(ind,[2:3]);
      C = crds(ij,:);                                            % Find midpoints for distances from specs matrix
      midpts(i,:) = pathmid(C);
   end;

   landmarks = unique1(landmarks);
   if(~isempty(help_pts))
      help_pts = unique1(help_pts);
   end;
   
   if(~isempty(ifscale))                                                   % Rescales the crds and specs to account for 
      crds = crds([4:r],:);                                                %    scalebar and first digitized point
      landmarks = landmarks - 3;
      help_pts = help_pts -3;
      specs(:,2) = specs(:,2) - 3;
      specs(:,3) = specs(:,3) - 3;
   end;
   
   x = crds(:,1);
   y = crds(:,2);
   
  % figure;                                                                 % Produce a plot of numbered coordinates
  % plotnumb(x,y);
  % putbounds(x,y);
  % axis equal;
  % axis off;
   
  % figure;                                                                 % Plot the helping points
   plot(x(help_pts),y(help_pts),'kx');
   hold on;
   plot(x(landmarks),y(landmarks),'k.');                                   % Plot the landmarks
   hold on;
   
   for k = 1:rs                                                            % Plot the distances
      x1 = specs(k,2);
      x2 = specs(k,3);
      plot([crds(x1,1) crds(x2,1)],[crds(x1,2) crds(x2,2)],'k');
   end;

   if(~isempty(values))                                                    % Plot corresponding values
      for l = 1:lenu
         hold on;
         txt = num2str(values(l));
         text(midpts(l,1),midpts(l,2),txt);
      end;
   end;
         
   putbounds(x,y);
   axis equal;
   %axis off;

return;