%RANDPTS:	Generates any number of sets of point coordinates from either a random,
%				clumped, or uniform distriubtion. The points can be generated within a 
%				square or circular domain.
%
%	USAGE:	crds = randpts(n,sets,{distrib},{c},{sigma},{arena},{size})
%	
%				crds = 		a [n x 2 x sets] matrix of point coordinates
%				----------------------------------------------------------
%				n = 			the number of points
%				sets = 		the number of sets of point coordinates to be generated
%				distrib =	optional, the type of food distribution
%									0 = random distribution {default}
%									1 = clumped distribution
%				c = 			optional, the number of clusters
%				sigma = 		optional, the standard deviation of the bivariate normal
%									distribution for each of the clusters {default = 3}
%				arena = 		optional, the shape of the arena
%									0 = square
%									1 = circle
%				size =		optional, the size of the arena {default = 50 cm}
%
%	Chris Higgins 5/31/2000

%
%	Modify: 6/17/01 - Make crds a 3D matrix

function crds = randpts(n,sets,distrib,c,sigma,arena,size)

   if(nargin < 2)
      sets = [];
   end;
   if(nargin < 3)												%	Alloate input arguments
      distrib = [];
   end;
   if(nargin < 4)
      c = [];
   end;
   if(nargin < 5)
      sigma = [];
   end;
   if(nargin < 6)
      arena = [];
   end;
   if(nargin < 7)
      size =[];
   end;
   
   if(isempty(sets))											%	Assign values to input arguments
      sets = 1;
   end;
   if(isempty(distrib))									
      distrib = 0;
   end;
   if(isempty(c))
      c = 3;
   end;
   if(isempty(sigma))
      sigma = 3;
   end;
   if(isempty(arena))
      arena = 0;
   end;
   if(isempty(size))
      size = 50;
   end;
   
   crds = zeros(n,2,sets);									% Allocate crds matrix
   
   if(distrib == 0)											%	Determine if random points
      if(arena == 0)											
         for i = 1:sets
            crds(:,:,i) = rand(n,2) * size;						% 	Generate points for square
         end;
      end;	
      if(arena == 1)
         crds = [];
         radius = size / 2;								%	Generate points for circle
         center = [(size / 2),(size / 2)];
         for j = 1:sets
            crds(:,:,j) = randcircle(n,radius,center);
         end;
      end;
	end;

   if(distrib == 1)											% 	Determine if clumped points
        if(arena == 0)
            border = [0 0;0 size;size size;size 0];	% 	Generate square border for points
            centpts = zeros(c,2,sets);
            for i = 1:sets
	            centpts(:,:,i) = rand(c,2) * size;					% 	Generate cluster centers for sqaure
            end;
        end;
        if(arena == 1)
	        radius = size / 2;
            center = [(size / 2),(size / 2)];
            centpts = randcircle(c,radius,center);		%	Generate cluster centers for circle
        end; 
        centpts
        m = n ./ c;	
   	    int = isintegr(m);
   	    if(int == 1)
            ptx = [];
            pty = [];
            for i = 1:sets
   			    for k = 1:c
                    x = normrnd(centpts(k,1),sigma,m,1);
                    y = normrnd(centpts(k,2),sigma,m,1);
                    ptx = [ptx;x];
                    pty = [pty;y];
                end;
                crds(:,1,i) = ptx;
                crds(:,2,i) = pty;
            end;
        else
      	    error('CLUMPEDPTS: The clusters must have an equal number of points');
        end;
    end;
return;

