% SAMPMEAN: Calculate the mean, the theoretical standard error and
%				the randomized standard error.
%
%	USAGE: 	[xbar, randse, theose] = sampmean(x,{iter})
%
%				xbar = the mean of the data matrix x
%				randse = the standard error of the random samples from x
%				theose = the standard error of the data matrix x
%				----------------------------------------------------------
%				x = a data vector
%				iter = optional, the number of iterations {default = 1000}
%
% 	Chris Higgins 11/1/1999
%
function [xbar,randse,theose] = sampmean(x,iter)

	if(min(size(x)) > 1)
      error('SAMPMEAN: The data matrix must be a vector.');	
	end;
  	if(nargin < 2)
     iter = 1000;
  	end;
  
 	n = length(x);
 	xbar = mean(x);
 	s = std(x);
  	theose = s ./ sqrt(n);
  	distrib = zeros(iter,1);
  
  	for i = 1:iter
     bx = sampwr(x,n);
     mbx = mean(bx);
     distrib(i) = mbx;
 	 end;
  
  	randse = std(distrib);
  	hist(distrib);
  	putxlab('Mean');
  
return;
  