% SHANCONF: Uses a bootstrapping procedure to resample the data to estimate a 
%           sampling distribution. It also determines a confidence interval
%           about the observed data from the distribution.
%
%   USAGE:  [lower,upper,shannon_index] = shanconf(x,iter,{alpha},{hist})
%
%           lower = the lower confidence limit for the distribution
%	         upper = the upper confidense limit for the distribution
%	         shannon_index = the Shannon diversity index value for the sample
%           ----------------------------------------------------------------
%	         x = an input data set in the form of a vector
%	         iter = the number of iterations
%           alpha = optional, alpha error {default = 0.05} 
%           hist = optional, flag that would plot a histogram {default = 0}
%
%   Chris Higgins 11/15/1999
% 

function [lower,upper,shannon_index] = shanconf(x,iter,alpha,histogram)
  if(min(size(x)) > 1)
     error('SHANCONF: The x input argument must be a vector.');
  end;
    if(nargin < 3)
     alpha = [];
  end;
  if(isempty(alpha))
     alpha = 0.05;
  end;
  if(alpha < 0)
     error('SHANCONF: The alpha error must be positive.');
  end;
  if(alpha > 1)
     error('SHANCONF: The alpha error must be less than one.');
  end;
  if(nargin < 4)
     histogram = 0;
  end;

  shannon_index = shannon(x);
  grps = makegrps(1:length(x),x);
  distrib = zeros(iter,1);
  for i = 1:iter
     sampx = sampwr(grps,sum(x));
     [ux,freqx] = unique1(sampx);
     distrib(i) = shannon(freqx);
  end;
  if(histogram == 1)
     figure;
     hist(distrib);
  end;
  [lower,upper] = conflimit(distrib,alpha);
return;

 

