%SHANTEST:  Accepts two vectors of counts and returns the observed diversity-index
%           values and the probability that the difference between them is
%           significantly different from zero.
% 
%   USAGE:  p_value = shantest(x,y,iter)
%             
%             p_value = the probability that the difference between them is significant
%             -------------------------------------------------------------------------
%             x = an input vector of data from one system
%             y = an input vector of data from another system
%             iter = the number of iterations  
%	      
% Chris Higgins 11/08/1999
%

function p_value = shantest(x,y,iter)

	if(min(size(x)) > 1)
        error('SHANTEST: The x input argument must be a vector.');
    end;
    if(min(size(y)) > 1)
        error('SHANTEST: The y input argument must be a vector.');
    end;
    if(length(x) ~= length(y))
        error('SHANTEST: The input vectors must be the same length.');
    end;
  
    if(nargin < 3)
        iter = [];
    end;
  
    if(isempty(iter))
     iter = 1000;
    end;
      
    shannon_index1 = shannon(x)
    shannon_index2 = shannon(y)
    delta_shannon = abs(shannon_index1 - shannon_index2);
 
    grps_x = makegrps(1:length(x),x);   
    grps_y = makegrps(1:length(y),y);
    grps = [grps_x;grps_y];

    distrib = zeros(iter,1);

    for i = 1:iter
        sampx = sampwr(grps,sum(x));
        [ux,freqx] = unique1(sampx);
        shannon_x = shannon(freqx);
     
        sampy = sampwr(grps,sum(y));
        [uy,freqy] = unique1(sampy);
        shannon_y = shannon(freqy);
     
        delta_d = abs(shannon_x - shannon_y);
        distrib(i) = delta_d;
    end;
  
    figure;
    hist(distrib);
    p_value = sum(distrib >= delta_shannon) ./ iter;
  
return;
  