% Swap:  This function produces a null model from binary data that maintains row and column totals.  Based on
%       independent swap in Gotelli and Entsminger (2001).
%
%   Usage: null = Swap(X,iter)
%
%       X = [r x c] binary input matrix
%       iter = optional, specifies how many transpositions to peform before null matrix if obtained
%           {default = r*c}
%       ---------------------------------------------------------------------------------------------------------
%       null = [r x c] = null model
%
%   Chris L. HIggins 3/27/2008
%
% Gotelli and Entsminger.  2001.  Swap and fill algorithms in null model analysis: rethinking the knight's tour.
%       Oecologia, 129: 281-291.
%
        

function null = Swap(X,iter)

    if(nargin < 2)                                          % Allocate input arguments
        iter = [];
    end;
    
    [r,c] = size(X);                                        % Determine size of original matrix
    
    if(isempty(iter))
        iter = r * c;
    end;
    
    null = X;
    
    for i = 1:iter
        stop1 = 0;
        stop2 = 0;
        while(stop1 < 1 & stop2 < (r*c))
            stop2 = stop2 + 1;            
            ColInd = ceil(rand(2,1) * c);                   % Select two random columns
            RowInd = ceil(rand(2,1) * r);                   % Select two random rows
            P1 = null(RowInd(1),ColInd(1));                 % 
            P2 = null(RowInd(1),ColInd(2));
            P3 = null(RowInd(2),ColInd(1));
            P4 = null(RowInd(2),ColInd(2));
            if((P1 == 1 & P2 == 0 & P3 == 0 & P4 == 1) | (P1 == 0 & P2 == 1 & P3 == 1 & P4 == 0))
                null(RowInd,ColInd) = null(flipud(RowInd),ColInd);
                stop1 = stop1 + 1;
            end;
        end;
    end;

return;