%TTEST1: 	Performs a T-test on the given data
%
%	Usage: 	p_value = ttest1(x,y,iter,(tail})
%
%				p_value = deviations as large or larger due to chance
%								alone in the direction or directions of the
%								alternate hypothesis
%				---------------------------------------------------------
%				x = a data vector
%				y = a data vector
%				iter = the number of iterations
%				tail = determines which direction or directions the 
%							alternate hypotheses are located
%						-1 : left-handed
%						 0 : two-tailed 	{default}
%						 1 : right-handed
%
%	Chris Higgins 1/26/2000
%

function p_value = ttest1(x,y,iter,tail)
	if(nargin < 4)
      tail = [];
   end;
   if(nargin < 3)
      iter = [];
   end;
   if(isempty(tail))
      tail = 0;
   end;
   if(isempty(iter))
      iter = 1000;
   end;

   t = tvalue(x,y);									% Test Statistic   
	dist = [x,y];   									% Pool data
   df = length(dist) - 2; 
   distrib = zeros(iter,1);						% Allocate matrix
        
   for i = 1:iter										% Random permutations
     r = randperm(length(dist));
     g = dist(r);
     a = g(1:length(x));
     b = g(length(y)+1:length(dist));
     distrib(i) = tvalue(a,b);
  	end;
     
   close all;  
   figure;
   hist(distrib);
   
   if(tail == 0)
      %p_value = 2.* (1 - tcdf(abs(t),df));
      left = (sum(distrib >= abs(t)) ./ iter);
      right = (sum(distrib <= -abs(t)) ./ iter);
      p_value =  left + right;
   elseif(tail > 0)
      %p_value = 1 - tcdf(t,df);
      p_value = sum(distrib >= t) ./ iter;
   else
      %p_value = tcdf(t,df);
      p_value = sum(distrib <= t) ./ iter;
   end;
   
return;