% Willig6: Calculates various measures of ecological diversity, including species richness, Shannon diversity,
%   Camargo evenness, Smith and Wilson evenness,Berger-Parker dominance, and rarity.
%
%   Usage: [S,H,Ec,Ev,D,R] = Willig6(X,def)
%
%       X = [Sites x Species] abundance matrix
%       TotSAD = optional, [1 x species] if passed, this vector of species abundances is used to assess global rarity; if nothing is 
%           passed, then local rarity is analyzed
%       --------------------------------------------------------------------------------------------------------------------------------
%       S = species richness
%       H = Shannon diversity
%       Ec = Camargo evenness
%       Ev = Camargo evenness
%       D = Berger-parker dominance
%       R = rarity
%
%   Chris L. Higgins 11/27/04
%

function [S,H,Ec,Ev,D,R] = Willig6(X,TotSAD)
    
    if(nargin < 2)
        TotSAD = [];
    end;
    
    [S,H] = shannon(X);                     % Species richness and Shannon diversity
    Ec = camargo(X);                        % Camargo evenness
    Ev = Evar(X);                           % Smith and Wilson evenness 
    D = bergerparker(X);                    % Berger-Parker dominance
    R = rarity(X,TotSAD);                   % Rarity

return;