% ALLZEROS: This function removes any column or row that contains all zeros
%
%   USAGE: Y = allzeros(X,rc)
%
%   X = original data matrix
%   rc = optional, specifies whether to remove rows, columns, or both
%       1 = rows
%       2 = columns
%       3 = both {default}
%   ----------------------------------------------------------------------
%   Y = new data matrix
%
%   Chris L. Higgins 3/16/2005
%

function Y = allzeros(X,rc)

    if(nargin < 2)                                                      % Allocate input arguments
        rc = [];        
    end;
    if(isempty(rc))
        rc = 3;
    end;

    [r,c] = size(X);                                                    % Determine size of input matrix
    
% Remove any row containing all zeros
    if(rc == 1)                                                         
        if(c == 1)
            Rsum = X;
        else;
            Rsum = rowsum(X);
        end;
        Rind = find(Rsum > 0);  
        Y = X(Rind,:);
    end;

% Remove any column containing all zeros
    if(rc == 2)                                                         
        if(r == 1)
            Csum = X;
        else;
            Csum = sum(X);
        end;
        Cind = find(Csum > 0);
        Y = X(:,Cind);
    end;

% Remove any row or column containing all zeros
    if(rc == 3)                                                         
        if(c == 1)
            Rsum = X;
        else;
            Rsum = rowsum(X);
        end;
        Rind = find(Rsum > 0);  
        Y = X(Rind,:);
                                                 
        if(r == 1)
            Csum = X;
        else;
            Csum = sum(X);
        end;
        Cind = find(Csum > 0);
        Y = Y(:,Cind);
    end;  
    
return;