%ASSIGNIND: Randomly assigns individuals into a matrix based on cell probabilities.
%
%   Usage: null = assignind(P,N,con)
%
%   P = a [r x c] matrix of cell probabilities 
%   N = the total number of individuals in the data matrix
%   con = optional, specifies any constraints on the placement of individuals
%       1 = no constraints {default}
%       2 = all islands must have a species (all row sums > 0)
%       3 = all species must be present (all column sums > 0)
%       4 = all islands and species must be present (all row and column sums > 0)
%   ---------------------------------------------------------------------------------
%   null = a [r x c] binary matrix of species abundance distriutions
%
%   Chris L. Higgins 3/19/2003
%

function null = assignind(P,N,con)

    if(nargin < 3)
        con = [];
    end;
    
    if(isempty(con))
        con = 1;
    end;

%     rand('seed', sum(100*clock));

    [r,c] = size(P);                        % Determine size of probability matrix
    
    X = P(:);
    X = X / sum(X);
    C = cumsum(X);
    
    stop = 0;
    while(stop == 0)
        null = zeros(r,c);
        for i = 1:N
            rnd = rand;
            ind = find(C >= rnd);
            null(ind(1)) = null(ind(1)) + 1;
        end;
        switch(con)
            case 1
                stop = 1;
            case 2
                island = rowsum(null);
                if(all(island > 0))
                    stop = 1;
                end;
            case 3
                species = sum(null);
                if(all(species > 0))
                    stop = 1;
                end;
            case 4
                island = rowsum(null);
                species = sum(null);
                if(all(island > 0) & all(species > 0))
                    stop = 1;
                end
        end;
    end;
    
return;