% BERGERPARKER: Returns a value of the Berger-Parker simple dominance measure.
%
%  USAGE: D = bergerparker(X,sd)
%
%      X = [Sites x Species] abundance matrix
%      sd = optional, specifies whether or not to inverse the index (default = 1)       
%      -------------------------------------------------------------
%      D = [Sites x 1] vector of Berger-Parker dominance measures
%           
% Chris Higgins 7/27/2004
%
%   Magurran, A.E. 2004.  Measuring Biological Diversity. Blackwell Publishing.
%       Malden, MA. 256 pps.

function D = bergerparker(X,sd)

    if(nargin < 2)
        sd = [];
    end;
    if(isempty(sd))
        sd = 1;
    end;

    [r,c] = size(X);                                        % Determine the number of sites
    if(r > 1 & c == 1)                                      % Convert column vector to row vector
        X = X';
        [r,c] = size(X);
    end;
    
    D = zeros(r,1);                                         % Allocate column vector for diversity indices
    for i = 1:r
        ind = find(X(i,:) > 0);                             % Find all non-zero entries
        if(isempty(ind))
            D(i) = 0;
        else
            Nmax = max(X(i,ind));
            N = sum(X(i,ind));                              % Calculate total number of individuals
            D(i) = Nmax/N;                                  % Calculate Berger-Parker index
            if(sd ~= 0)
                D(i) = 1/D(i);
            end;
        end;
    end;
  
return; 