% BESTGEOK: This function determines the k parameter of the geometric series that best fits
%   the data. The best fit "k" can be optimized by either a sum-of-squares or chi-squared criteria.
%
%   Usage: [k,SS] = bestgeok(data,fxn,stat)
%
%   data = a [r x c] matrix of species abudances where the rows correspond to sites and the columns
%       correspond to species
%   fxn = specifies the function to use in the optimization routine
%   stat = optionsal, speficies which optimization statistic to used in the fitting
%       0 = sum of absolute deviations {default}
%       1 = sum of squared deviations 
%       2 = chi-squared deviations
%   ------------------------------------------------------------------------------------------------
%   k = a [r x 1] vector containg the best estimate of "k" for each site
%
%   Chris L. Higgins 3/10/2003
%

function k = bestgeok(data,fxn,stat)

    if(nargin < 2)
        stat = [];
    end;
    
    if(isempty(stat))
        stat = 0;
    end;
    
    [r,c] = size(data);                                     % Determine size of data matrix
    
    k = zeros(r,1);                                         % Allocate vector for k estimates
   
    for i = 1:r                                             % Cycle through each "site"
        ind = find(data(i,:) > 0);                          % Find the species with positive abundance
        Obs = data(i,ind);                                  % Pull those species into another vector
        Obs = fliplr(sort(Obs));                            % Rank species according to abundance from high to low
        S = length(ind);                                    % Calculate species richness 
        N = sum(Obs);                                       % Calculate total number of individuals
        
        kest = 0.5;                                         % Set initial value of k to zero
        kest = fminsearch(fxn,kest,[],Obs,stat);            % Optimization routine
        k(i) = kest;                                        % Place best ke estimates into vector
    end;
           
return;