% BEZIER: This function will create a series of point coordinates that correspond to a simple
%   Bezier curve, which is defined by four points. The four defining point include the point of
%   origin, the destination point, and two control points. 
%
%   Usage: curve = bezier(pts,n,doplot)
%
%   pts = a [4 x 2] matrix of point cordinates defining the Bezier curve with the first row
%           corresponding to the origin and the last row corresponding to the destination point
%   n = optional, specifies the number of points used to create the curve {default = 50}
%   doplot = optional, specifies whether of not to plot the Bezier curve
%   ----------------------------------------------------------------------------------------------
%   curve = a [n+1 x 2] matrix of point coordinates that specifies the Bezier curve
%
%   Chris L. Higgins 2/1/2003
%
%   See http://www.moshplant.com/direct-or/bezier/math.html formore details

function curve = bezier(pts,n,doplot)

    if(nargin < 2)
        n = [];
    end;
    if(nargin < 3)
        doplot = [];
    end;
    
    if(isempty(n))
        n = 50;
    end;
    if(isempty(doplot))
        doplot = 0;
    end;

    cx = 3*(pts(2,1) - pts(1,1));
    bx = 3*(pts(3,1) - pts(2,1)) - cx;
    ax = pts(4,1) - pts(1,1) - cx - bx;
        
    cy = 3*(pts(2,2) - pts(1,2));
    by = 3*(pts(3,2) - pts(2,2)) - cy;
    ay = pts(4,2) - pts(1,2) - cy - by;
    
    t = 0;
    delta = 1/n;
    
    for n = 1:n+1
        x(n) = ax*t^3 + bx*t^2 + cx*t + pts(1,1);
        y(n) = ay*t^3 + by*t^2 + cy*t + pts(1,2);  
        t = t + delta;
    end;

    if(doplot > 0)
        plot(x,y);
    end;

    curve = [x' y'];
    
return;