% BEZIERAREA: This function calculates the difference between the area behind a Bezier curve and
%   the percent fill of the original data matrix.
%
%   Usage: D = bezierarea(p,data,fill)
%
%   p = the porportion of the length of a matrix specifiying the control points of teh Bezier curve
%   data = [r x c] data matrix with rows representing "islands" and columns representing "species"
%   fill = the percentage of cells that contain "presences"
%   ------------------------------------------------------------------------------------------------
%   D = the squared difference between the percent area behine the curve and the percent fill
%
%   Chris L. Higgins 3/12/2003
%

function D = bezierarea(p,data,fill)

    [r,c] = size(data);                         % Determine the size of the data matrix

    if(fill < 50)
        Cpt1 = [0.5 (0.5+(p*(r-1)))];
        Cpt2 = [((c-0.5)-(p*(c-1))) r-0.5];
        pts = [0.49 0.49;Cpt1;Cpt2;c-0.49 r-0.49];
    else;
        Cpt1 = [(0.5+(p*(c-1))) 0.5];
        Cpt2 = [c-0.5 ((r-0.5)-(p*(r-1)))];
        pts = [0.49 0.49;Cpt1;Cpt2;c-0.49 r-0.49];
    end;
    
    curve = bezier(pts,50,0); 

    L = length(curve);                          % Determine the number of points in the curve    

    r = ceil(curve(L,2));                       % Determine the number of rows in the data matrix
    c = ceil(curve(L,1));                       % Determine the number of columns in the data matrix
    
    LineX = ptsline([0 0],[c 0]);               % Calculate line for bottom axis
    LineY = ptsline([0 0],[0 r]);               % Calculate line for left axis
    LineR = ptsline([0 r],[c r]);               % Calculate line for top margin
    LineC = ptsline([c 0],[c r]);               % Calculate line for right Margin
    
    L0 = ptsline(curve(1,:),curve(2,:));        % Find equation for first line in Bezier curve
    ptX0 = ptinter(L0,LineX);                   % Determine where the first line crosses the X axis
    ptY0 = ptinter(L0,LineY);                   % Determine where the first line crosses the Y axis
    if(ptX0(1) < 0)                             % Determine which point of intersection belongs in polygon
        polypt1 = [0 r; ptY0];
    else;
        polypt1 = [0 r;0 0;ptX0];
    end;
    
    L1 = ptsline(curve(L-1,:),curve(L,:));      % Find equation for last line in Bezier curve
    ptX1 = ptinter(L1,LineR);                   % Determine where the last line crosses the X axis
    ptY1 = ptinter(L1,LineC);                   % Determine where the lastt line crosses the Y axis
    if(ptX1(1) > c)                             % Determine which point of intersection belongs in polygon
        polypt2 = [ptY1;c r;0 r];
    else;
        polypt2 = [ptX1;0 r];
    end;
    
    polypts = [polypt1;curve;polypt2];          % Define a set of points that creates a polygon in the upper left corner
    area = polyarea(polypts);                   % Calculate area of polygon
    perarea = (area / (r * c)) * 100;           % Calculate percentage of coordinate space

    D = (fill - perarea)^2;                     % Calculate the difference between fill and perarea
    
return;