% BOOTSAMP2:  Randomly samples a vector of species abundances based on
%   the number of individuals.  That is, it creates a bootstrapped sample
%   of N observations from X distribution.  Used in rarefaction (RAREFY).
%
%   Usage: Y = bootsamp2(X,N)
%
%   X = vector of species abundances
%   N = number of individuals to sample
%   ---------------------------------------------------------------------
%   Y = bootstrapped vector of species abundances

function Y = bootsamp2(X,N)
    
    lenX = length(X);                   % Determine total number of species
    Z = makegrps([1:lenX],X);           % Create vector of individuals
    Xsamp = samplewr(Z,N);              % Sample with repacement from vector
    [u,f] = unique1(Xsamp);             % Find unique species and abundances
    Y = f';                             % Put in proper vector form
   
return