%BOOTSAMPLE: Randomizes a sample from either a data vector or a data matrix
%
%	USAGE:	bx = bootsample(X,{grps})
%			
%				X = the input argument
%				grps = optional, input grouping argument {default = ones}				
%				--------------------------------------------------------------
%				bx = the new bootstrapped values for the x matrix
%
% Chris Higgins 11/08/1999
%
%	STAND ALONE
%

function bx = bootsample(X,grps)
    
    if(nargin < 2)                                  % Allocate input arguements
        grps = [];
    end;
    if(isempty(grps))
        grps = ones(length(X),1);
    end;
    
    if(min(size(grps)) > 1)
        error('BOOTSAMPLE: The groups argumnet must be a vector.');
    end;
    if(length(grps) ~= length(X))
        error('BOOTSAMPLE: The grouping vector must be the same length as x.');
    end;
    
    [r,c] = size(X);                                % Determines the size of the data matrix
    
    grp_ids = unique1(grps);
    ngrps = length(grp_ids);
    bx = zeros(size(X));
   
    for i = 1:c
        for j = 1:ngrps
            f = find(grps == grp_ids(j));
            bx(f,i) = samplewr(X(f,i));
        end;
    end;
   
 return;