% BOUNDFILL:  This function fills in the boundaries as described in Leibold and Mikkelson.
%
%   USAGE: Y = boundfill(X,Comm)
%
%   X = [sites x species] incidence matrix
%   Comm = specifies whether or not to consider ranges (0) or communities (1)
%   ----------------------------------------------------------------------------------------------------------
%   Y = filled matrix
%
%   Chris L. Higgins 3/14/2005
%
%   Leibold,M.A. and Mikkelson,G.M.  2002.  Coherence, species turnover, and boundary clumping: elements 
%       of meta-community structure.  Oikos 97: 237-250.

function Y = boundfill(X,Comm)

    [sites,species] = size(X);
    Y = X;
    
    if(Comm == 0)
        for i = 1:species
            ind1 = find(X(:,i) == 1);
            First = ind1(1);
            Last = ind1(length(ind1));
            Y([First:Last],i) = 1;
        end;
    end;
    
    if(Comm == 1)
        for i = 1:sites
            ind1 = find(X(i,:) == 1);
            First = ind1(1);
            Last = ind1(length(ind1));
            Y(i,[First:Last]) = 1;
        end;
    end;
       
return;    