% BOUNDFIND: This function finds the first and last species that are found at a given sites and also finds
%   the first and last sites at which a species occurs.
%
%   USAGE: [FirstSpecies,LastSpecies,FirstSite,LastSite] = boundfind(X)
%
%   X = [sites x species] incidence matrix
%   ---------------------------------------------------------------------
%   FirstSpecies = [r x 1] vector of first species
%   LastSpecies = [r x 1] vector of last species
%   FirstSite = [1 x c] vector of first sites
%   LastSite = [1 x c] = vector of last sites
%
%   Chris L. Higgins 3/14/2005
%
%   Leibold,M.A. and Mikkelson,G.M.  2002.  Coherence, species turnover, and boundary clumping: elements 
%       of meta-community structure.  Oikos 97: 237-250.

function [FirstSpecies,LastSpecies,FirstSite,LastSite] = boundfind(X)

    [r,c] = size(X);
    
    FirstSpecies = zeros(r,1);                      % Allocate matrices
    LastSpecies = zeros(r,1);
    FirstSite = zeros(1,c);
    LastSite = zeros(1,c);

% Cycle through sites to find the first and last species at each site
    for i = 1:r                                     
        ind = find(X(i,:) == 1);
        if(isempty(ind))
            FirstSpecies(i) = 0;
            LastSpecies(i) = 0;
        else;
            FirstSpecies(i) = ind(1);
            LastSpecies(i) = ind(length(ind));
        end;
    end;

% Cycle through columns to determine the first and last site where each species occurs
    for i = 1:c
        ind = find(X(:,i) == 1);
        if(isempty(ind))
            FirstSite(i) = 0;
            LastSite(i) = 0;
        else;
            FirstSite(i) = ind(1);
            LastSite(i) = ind(length(ind));
        end;
    end;
    
return;