% BRAYCURTIS: Calculates the Bray-Curtis (Sorensen quantitative) similarity index.
%
%   Usage:  [Cn,CnCI] = braycurtis(X)
%
%           X = [sites x species] matrix of abundances
%           -------------------------------------------------------------------------
%           Cn = [sites x sites] symmetric matrix of indices
%           CnCI = [sites x sites*2] matrix of confidence intervals
%
%   Chris L. Higgins 7/15/2004
%
%   Magurran, A.E. 2004.  Measuring Biological Diversity. Blackwell Publishing.
%       Malden, MA. 256 pps.
%

function [Cn,CnCI] = braycurtis(X,iter)

    if(nargin < 2)
        iter = [];
    end;
    

    [r,c] = size(X);
    Tot = rowsum(X);
    Cn = ones(r,r);
    
    for i = 1:(r-1)
        for j = (i+1):r
            A = 0;
            for k = 1:c
                A = A + min([X(i,k) X(j,k)]);
            end;
            Cn(i,j) = (2*A) / (Tot(i) + Tot(j));
            Cn(j,i) = Cn(i,j);
        end;
    end;
    
    if(~isempty(iter))
        CnB = zeros(r,r,iter);
        for it = 1:iter
            Y = bootsamp1(X);
            for i = 1:(r-1)
                for j = (i+1):r
                    A = 0;
                    for k = 1:c
                        A = A + min([Y(i,k) Y(j,k)]);
                    end;
                    CnB(i,j,it) = (2*A) / (Tot(i) + Tot(j));
                    CnB(j,i,it) = CnB(i,j,it);
                end;
            end;
        end;
    
        %CnCI = [];
        for i = 1:(r-1)
            %CIA = [];
            for j = (i+1):r
                X = bootci(CnB(i,j,:));
                X = X(:);
                CI = bootci(X)';
                CnCI(j,i) = CI(1);
                CnCI(i,j) = CI(2);
            end;
            %CnCI = [CnCI;CIA];
        end;
    end;
    
return;