% CAMARGO: Returns a value of the Camargo evenness measure.
%
%  USAGE: Ec = camargo(X)
%
%         X = [Sites x Species] abundance matrix
%         -------------------------------------------------------------
%         Ec = [Sites x 1] vector of Camargo evenness measures
%           
% Chris Higgins 7/27/2004
%
%   Camargo, J.A. 1993.  Must dominance increase with the number of subordinate species
%       in competitive interactions? Journal of Theoretical Biology, 161: 537-542.
%
%   Magurran, A.E. 2004.  Measuring Biological Diversity. Blackwell Publishing.
%       Malden, MA. 256 pps.

function Ec = camargo(X)

    [r,c] = size(X);                                        % Determine the number of sites
    if(r > 1 & c == 1)                                      % Convert column vector to row vector
        X = X';
        [r,c] = size(X);
    end;
    
    Ec = zeros(r,1);                                        % Allocate column vector for diversity indices
    for i = 1:r
        ind = find(X(i,:) > 0);                             % Find all non-zero entries
        if(isempty(ind))
            Ec(i) = 0;
        else
            S = length(ind);
            N = sum(X(i,ind));
            P = X(i,ind)./N;
            e = 0;
            for j = 1:S
                for k = j+1:S
                    e = e + (abs(P(j) - P(k))/S);
                end;
            end;
            Ec(i) = 1-e;                                    % Calculate Camargo eveneness
        end;
    end;
  
return; 