% CIRCLE: 	Given a radius, center point, and number of points to be returned
%				(all optional arguments), returns a set of point coordinates 
%				that can be used to plot the circle.
%
%	Usage: 	pts = circle({radius},{center},{n},{plotflag})
%
%				pts = an [nx2] matrix of point coordinates
%				------------------------------------------------------
%				radius = optional radius of circle {default = 1}.
%				ceneter = optional vector (length 2) of (x,y) coordinates
%								of the center of the circle {default = [0,0]}.
%				n = optional number of coordinates to be returned
%						{default = 100}. For small values of n, the plot
%						will produce an (n-1)-sided polygon inscribed within
%						the circle.Increasing the number of points will 
%						increase the smoothness of the plotted circle.
%				plotflag = optional, plots the circle
%
%
% Chris Higgins, 10/13/1999
%

function pts = circle(radius,center,n,plotflag)

	if (nargin < 1)
		radius = [];
	end;
	if (nargin < 2)
		center = [];
	end;
	if (nargin < 3)
		n = [];
   end;
   if(nargin < 4)
      plotflag = [];
   end;
   
	if (isempty(radius))
		radius = 1;
	end;
	if (isempty(center))
		center = [0,0];
	end;
	if (isempty(n))
		n = 100;
	end;
   if(isempty(plotflag))
      plotflag = 0;
   end;
   
   theta = linspace(0, 2.*pi, n);
	x = radius .* cos(theta) + center(1);
   y = radius .* sin(theta) + center(2);
   pts = [x' y'];
   if(plotflag == 1)
      plot(pts(:,1),pts(:,2));
   end;
return;