% COMPOSITEF: This is the objective function for BESTGEOK. That is, it creates the expected
%   values from a geometric distributions that correspond to the number of species, total
%   number of individuals, and a k value and measures the deviations of the expected values
%   from some set of observed values.
%
%   Usage: dev = bestgeokf(kest,Obs,stat)
%
%   kest = a estimated value for the proportion of resources consumed by each additional species
%   Obs = a vector of observed values
%   stat = optionsal, speficies which optimization statistic to used in the fitting
%       0 = sum of absolute deviations {default}
%       1 = sum of squared deviations 
%       2 = chi-squared deviations
%   ---------------------------------------------------------------------------------------
%   dev = the value of the test statistic
%
%   Chris L. Higgins 3/10/2003
%

function dev = compositef(kest,data,stat)

    [r,c] = size(data);

    for i = 1:r
        ind = find(data(i,:) > 0);
        Obs = data(i,ind);
        Obs = abs(sort(-Obs));
        S = length(ind);
        N = sum(Obs);
        Exp = composite(S,N,kest);
        switch(stat)
            case 0
                D(i) = absdev(Obs,Exp);
            case 1
                D(i) = sumsqdev(Obs,Exp);
            case 2
                D(i) = chi2(Obs,Exp);
        end;
    end;

    dev = sum(D);
    
return;