% CSCORE: The C-score measures the average number of "checkerboard units" between all possible pairs of species.
%   Stone and Roberts (1990)
%
%   USAGE: C = cscore(X)
%
%   X = [sites x species] incidence matrix
%   ------------------------------------------
%   C = C-score
%
%   Chris L. Higgins 3/20/05
%

function C = cscore(X)

    [r,c] = size(X);
    Richness = rowsum(X);
    Incidence = sum(X);
    C = 0;
    for i = 1:c-1
        for j = i+1:c
            ind1 = find(X(:,i) == 1);
            ind2 = find(X(:,j) == 1);
            S = sum(isin(ind1,ind2));
            R1 = sum(X(:,i));
            R2 = sum(X(:,j));
            C = C + ((R1-S)*(R2-S));
        end;
    end;
    C = C / comb(c,2);
    
return;