% DISPERSAL:  This function uses computer simulations to assess whether or not random walks and dispersal abilities can give
%               rise to nestedness


function [PA,NestC,Totwalk] = dispersal(sp,ind,SAD,diff,numsteps,step,r)

% Specifies the grid to which sampling sites are located -- corresponds to Big Grid

    grid = [30 30;90 30;150 30;210 30;270 30;30 90;90 90;150 90;210 90;270 90;
            30 150;90 150;150 150;210 150;270 150;30 210;90 210;150 210;210 210;270 210;
            30 270;90 270;150 270;210 270;270 270;30 330;90 330;150 330;210 330;270 330;
            30 390;90 390;150 390;210 390;270 390;30 450;90 450;150 450;210 450;270 450];
 
    grid2 = (grid+30)/60;
    
% Specifies the border of the arena -- used to reflect the random walks

    border = [0 0;300 0;300 480;0 480;0 0];

% Specifies the species abundance distribution to use in the simulations

    if(SAD == 1)
        Abundance = uniform(sp,ind,1);
    end;
    if(SAD == 2)
        Abundance = domindecay(sp,ind,1);
    end;
    if(SAD == 3)
        Abundance = randassort(sp,ind,1);
    end;
    if(SAD == 4)
        Abundance = preemption(sp,ind,1);
    end;
    
    Grps = makegrps([1:sp],Abundance);
    
    
    walktype = 2;
    
    if(diff == 0)
        for i = 1:sum(Abundance)
            [Walk(i,:),Totwalk(:,:,i)] = dispersalwalk(border,numsteps,walktype,step,r);
        end;
    end;
    if(diff == 1)
        Steps = makegrps([1:5],sum(Abundance)/5);
        for i = 1:sum(Abundance)
            [Walk(i,:),Totwalk(:,:,i)] = dispersalwalk(border,numsteps,walktype,Steps(i),r);
        end;
    end;

    Site = ceil(Walk/60);
    
    PA = zeros(sp,length(grid));
    figure;
    for i = 1:length(grid)
        ind = find(Site(:,1) == grid2(i,1) & Site(:,2) == grid2(i,2));
        plotnumb1(grid2(i,1),grid2(i,2),length(ind));
        hold on;
        axis([0.5 5.5 0.5 8.5]);
        puttick([1:5],[1:8]);
        if(~isempty(ind))
            [u,f] = unique1(Grps(ind));
            for j = 1:length(u)
                PA(u(j),i) = f(j);
            end;
        end;
        u = [];
        f = [];
    end;
    
    X = makebinary(PA);
    [Nc,PNc,PvNc,C,PvC] = nestnc(X);
    NestC = [C PvC];
    
return;