%DISPERSALWALK:		Determines the random walk path generated from the origin and a series of coordinates. 
%
%		USAGE:	walk = dispersalwalk(pts,{size},)
%				
%       border = specifies the border with which the random walk is constrained
%       numsteps = specifies the number of steps in the random walk
%       walktype = specifies the type or random walk (Pearson = 1; Levy = 2; Gaussian = 3)
%       step = specifies the step length
%       r = specifies the type of random angle (360 uniform = 0; 180 uniform = 1; 180 normal = 2)
%       ----------------------------------------------------------------------------------------------------
%
%	Chris Higgins 5/22/2000
%
%	REQUIRES: isinpoly, euclidist

% Modified: 2/27/02 - include path between food items (total_walk)
%           5/23/02 - include biased walks

function [walk,Totwalk] = dispersalwalk(border,numsteps,walktype,step,r)

    Site = [0 0];
    
    randtheta = 0;
    walk = [rand*300 rand*480];
    Totwalk = [];
    stop = 0;
    steps = 0;
    while(steps < numsteps)

        if(r == 0)
            theta = rand .* pi; 			                % Generate uniform random angle
            rnd = round(rand);
            if(rnd == 0)
                thetha = -theta;
            end;
            randtheta = randtheta + theta;
        end;      
        if(r == 1)
            theta = rand .* (pi ./ 2);                      % Generate uniform angle with AMT of 180
            rnd = round(rand);
            if(rnd == 0)
                theta = -theta;
            end;
            randtheta = randtheta + theta;
        end;
        if(r == 2)                                          % Generate turn angle form normal dist. with sd = pi/4
            a = 0;
            while(a == 0)
                theta = normrnd(0,(pi./4));
                if(-pi < theta < pi)
                    a = 1;
                end;
            end;
            randtheta = randtheta + theta;
        end;
    
        if(randtheta > pi)                                  % Alter angle to allow for correct coordinates
            randtheta = randtheta - (2 * pi);
        end;
        if(randtheta < -pi)
            randtheta = randtheta + (2 * pi);
        end; 
      
        if(walktype == 1)
            steplength = step; 	                            % Generate random step length (Pearson random walk)
        end;
        if(walktype == 2)
            steplength = abs(exprnd(step)); 	   	        % Generate random step length (Levy random walk)
        end;
        if(walktype == 3)
            steplength = abs(normrnd(step,(step/2)));	    % Generate constant step length (Gaussian random walk)
        end;
    
        x = cos(randtheta) .* steplength;		            % Calculate coordinates of new step
        y = sin(randtheta) .* steplength; 
     
        w(1) = walk(1) + x;							        % Calculate possible walk from new step
        w(2) = walk(2) + y;							
      
        isin = isinpoly(w,border);					        % Determine if the new step is within the boundaries of the arena
                                                        
        if(isin == 1)									    % If new step is within boundaries:
            walk(1) = w(1);							        % Add new step to walk
            walk(2) = w(2);
            Totwalk = [Totwalk;walk(1) walk(2)];
            steps = steps + 1;
        end;
    end;
   
return;