% DIVERSITY: Calculates various measures of ecological diversity, including species richness, Shannon diversity,
%   Camargo evenness, Berger-Parker dominance, and rarity.
%
%   Usage: [S,H,E,D,R] = diversity(X,def)
%
%       X = [Sites x Species] abundance matrix
%       TotSAD = optional, [1 x species] if passed, this vector of species abundances is used to assess global rarity; if nothing is 
%           passed, then local rarity is analyzed
%       --------------------------------------------------------------------------------------------------------------------------------
%       S = species richness
%       H = Shannon diversity
%       E = Camargo evenness
%       D = Berger-parker dominance
%       R = rarity
%fuck
%   Chris L. Higgins 11/27/04
%

function [S,H,E,D,R] = diversity(X,TotSAD)
    
    if(nargin < 2)
        TotSAD = [];
    end;
    
    [S,H] = Shannon(X);                     % Species richness and Shannon diversity
    E = camargo(X);                         % Camargo evenness
    D = bergerparker(X);                    % Berger-Parker dominance
    R = rarity(X,TotSAD);                   % Rarity

return;