% DIVERSITYDIFF:

function Div = diversitydiff(A,B,iter)

    if(nargin < 3)                                  % Establish default value for number of iterations
        iter = [];
    end;
    if(isempty(iter))
        iter= 1000;
    end;
    
    [ra,ca] = size(A);                              % Determine size of community A
    [rb,cb] = size(B);                              % Determine size of community B
    
    if(ra > 1 & ca == 1)                            % Make sure data vector is a column vector
        A = A';
    end;
    if(rb > 1 & cb == 1)
        B = B';
    end;

    [Sa,Ha,Ea,Da,Ra] = diversity(A);                % Estimate diversity indices for community A
    [Sb,Hb,Eb,Db,Rb] = diversity(B);                % Estimate diversity indices for community B

    DS = Sa - Sb;                                   % Calculate the difference in indices between communities
    DH = Ha - Hb;
    DE = Ea - Eb;
    DD = Da - Db;
    DR = Ra - Rb;
    
    IndA = makegrps([1:ca],A);                      % Create vector of individuals that correspond to community A
    IndB = makegrps([1:cb],B);                      % Create vector of individuals that correspond to community B
    Uni = [IndA;IndB];                              % Combine two communities into one universe
    TotInd = length(Uni);                           % Calculate total number of individuals in universe
    
    for i = 1:iter
        r = randperm(TotInd);                       % Randomly permute individuals (sample without replacement)
        RIndA = Uni(r(1:length(IndA)));             % Allocate random individuals to community A
        RIndB = Uni(r(length(IndA)+1:TotInd));      % Allocate random individuals to community B
        [u,A] = unique1(RIndA);                     % Convert indidividual vector to species vector
        [u,B] = unique1(RIndB);                     % Convert individuals to species vector
        
        [RSa,RHa,REa,RDa,RRa] = diversity(A');      % Estimate diversity indices for randomized community A
        [RSb,RHb,REb,RDb,RRb] = diversity(B');      % Estimate diversity indices for randomized community B
        
        RDS(i) = RSa - RSb;                         % Calculate the difference in indices between communities
        RDH(i) = RHa - RHb;
        RDE(i) = REa - REb;
        RDD(i) = RDa - RDb;
        RDR(i) = RRa - RRb;
    end;
    
    pS = pvalue(DS,RDS,2);                          % Determine p-values for each diversity index
    pH = pvalue(DH,RDH,2);
    pE = pvalue(DE,RDE,2);
    pD = pvalue(DD,RDD,2);
    pR = pvalue(DR,RDR,2);

    Div = [Sa Sb pS;Ha Hb pH;Ea Eb pE;Da Db pD;Ra Rb pR];   % Place indices and pvalues in one outpur matrix
    
return;