% DOMINDECAY: This function provides the expected species abundances based on Tokeshi (1990) model
%   of "Dominance Decay." In this model, "a new species always invades the niche space of the most
%   abundant species of an existing assemblage." 
%
%   Uasge:  Abundance = domindecay(S,N,rel)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   rel = optional, specifies whether or not to make the abundances relative {default = 0}
%   -------------------------------------------------------------------------------------------
%   Abundance = a [S x 1] vector of expected species abundances 
%
%   Chris L. Higgins 3/5/2003
%
%   Tokeshi, M. 1990. Niche apportionment or random assortment: species abundance patters revisited.
%       Journal of Animal Ecology, 59: 1129-1146.       
%

function Abundance = domindecay(S,N,c,rel)

    if(nargin < 3)
        c = [];
    end;
    if(nargin < 4)
        rel = [];
    end;
    
    if(isempty(c))
        c = 0;
    end;
    if(isempty(rel))
        rel = 0;
    end;

    Abundance = zeros(1,S);
    available = N;
    
    x = [0 1];
       
    for i = 1:S
        for m = 2:length(x)
            Dist(m-1) = (x(m) - x(m-1));
        end;
        ind = find(Dist == max(Dist));
        rx = rand * max(Dist);
        s = x(ind) + rx;
        x = [x s];
        x = sort(x);
    end;
    
    for j = 1:S
        Ab(j) = (x(j+1) - x(j)) * N;
    end;
   
    Abundance = abs(sort(-Ab));

    if(c == 1)
        Abundance = ceil(Abundance);
    end;
    
    if(rel ~=0)
        Abundance = Abundance / N;
    end;
    
return;