% EMBEDABS:  This function counts the number of embedded absences within a presence-absence matrix.  Embedded
%             absences are interruptions in a range of community and assesses coherence.  Zeros that are in
%            within the boundaries of both ranges and communities ar only counted once.
%
%   USAGE: Abs = embedabs(X)
%
%   X = [sites x species] incidence matrix
%   ---------------------------------------------------------------------
%   Abs = the number of embedded absences
%
%   Chris L. Higgins 3/14/2005
%
%   Leibold,M.A. and Mikkelson,G.M.  2002.  Coherence, species turnover, and boundary clumping: elements 
%       of meta-community structure.  Oikos 97: 237-250.


function Abs = embedabs(X)

    [sites,species] = size(X);

    [FirstSpecies,LastSpecies,FirstSite,LastSite] = boundfind(X);       % Find boundaries for matrix
    
    Abs = 0;    
    for i = 1:sites                                                     % Cycle through sites
        for j = 1:species                                               % Cycle through species        
            if(X(i,j) == 0)
                flag = 0;
                if(j > FirstSpecies(i) & j < LastSpecies(i))            % Find absences within sites
                    Abs = Abs + 1;
                    flag = 1;
                end;
                if(i > FirstSite(j) & i < LastSite(j) & flag == 0)      % Find absences within species
                    Abs = Abs + 1;
                end;
            end;
        end;
    end;
    
return;