function [theta,m,intermed]=esthub(abunds,nruns,bDraw)
% [theta,m,intermed]=esthub(abunds[,nruns=50[,bDraw=0]])  
%      nruns defaults to 50 - gives measure of time vs precision tradeoff
%      if nruns<0, then fits theta only (no m) w/ |nruns|
if nargin<3, bDraw=0; end
if nargin<2, nruns=50; end
bThetaOnly=0;
if nruns<0, nruns=-nruns; bThetaOnly=1; end 

J=sum(abunds);
abunds=-sort(-abunds);
ma=median(abunds);
hiabs=convab(abunds,ma);
allabs=convab(abunds,0);
nspec=length(abunds); 
%estimte theta via two step interp
%
% double run on theta - once with breadth, once with depth
%
theta1=[1 3 5 10 25 35 50 75 100 125 150 175 200];
%theta1=[50 75];
dists1=findbestparam(hiabs,theta1,J,1.0,100,ma,nspec); 
[junk,idx]=max(dists1);
if idx==1,
   theta2=[0.1 0.5 0.8 1.0 1.3 1.7 2.0 2.5 3.0];
elseif idx==length(theta1),
   theta2=[175 185 190 200 210 220 250 300];
else
   idx=round(mean(find(dists1==dists1(idx))));
   theta2=linspace(theta1(idx-1)*.9,theta1(idx+1)*1.1,10);
end
dists2=findbestparam(hiabs,theta2,J,1.0,100,ma,nspec); 
[junk,idx]=max(dists2);
theta=theta2(idx);
if bThetaOnly,
    intermed={theta1 dists1; theta2 dists2};
    DoDraw(bDraw,theta,J,1,abunds);
   return;
end

%
%now run on m
%
m1=[0.001 0.05 0.07 0.1 0.15 0.2 0.5 0.9]; 
dists3=findbestparam(allabs,theta,J,m1,nruns,0,nspec); 
[junk,idx]=max(dists3);
if idx==1,
   m2=[0 0.000001 0.0001 0.001];
elseif idx==length(m1),
   m2=[0.9 0.93 0.96 0.99 1.0];
else
   idx=round(mean(find(dists3==dists3(idx))));
   m2=[exp(linspace(log(m1(idx-1)*0.9),log(m1(idx)),5)) exp(linspace(log(m1(idx)),log(m1(idx+1)*1.1),5))];
end
dists4=findbestparam(allabs,theta,J,m2,nruns,0,nspec);
[junk,idx]=max(dists4);
m=m2(idx);

intermed={theta1 dists1; theta2 dists2; m1 dists3; m2 dists4};

DoDraw(bDraw,theta,J,m,abunds);
return;

function DoDraw(bDraw,theta,J,m,abunds)
if bDraw,
   [mn,var]=myhubeng(theta,J,m,100,0,1e6);
   hubplot(mn{1},var{1},abunds);
end
return

function dists=findbestparam(obsab,thetas,J,m,nruns,ma,nspec) 
Jtrial=J;
engabs=myhubeng(thetas,Jtrial,m,nruns,0,1e6);
nparams=length(engabs);
dists=zeros(nparams,1);
bWarnedObsZero=0;
for i=1:nparams,
    % go from list of abundances to histogram
    truncabs=engabs{i};
    stopmode=getglobal('HUBSTOP');
    if isempty(stopmode), stopmode=2; end %default to same # species
    switch stopmode
    case 0, % no truncation
        ;
    case 1, %truncate if N<1
        truncabs=truncabs(find(truncabs>=1));
    case 2, %truncate to same # species
        if length(truncabs)>nspec,
            truncabs(nspec+1:end)=[];
        end;
    end
    trialabs=convab(truncabs,ma);
   
   % ensure same length
   if length(trialabs)<length(obsab), trialabs(length(obsab))=0; end
   if length(obsab)<length(trialabs), obsab(length(trialabs))=0; end
   trialabs=trialabs(:);
    
   % handle zero's - book doesn't really give method for this
   %trialabs==0 --> log(0) & trialabs (expectation) should be >0 so
   if any(trialabs==0),
       %fprintf('Penalized case\n');
       trialabs(find(trialabs==0))=1; %avoid log(0), but still w/ stiff penalty
   end
   %obsab==0 --> 0*log(x/0) which is 0 in limit, so ignore these cases for first term
   nzobs=find(obsab>0);
   
   % calculate Likelihood (presumbably Log Likelihood but book doesn't say)
   dists(i)=sum(obsab(nzobs).*log(trialabs(nzobs)./obsab(nzobs)))-sum((trialabs-obsab));
   % X2 distances
   %dists(i)=-sum((obsab-trialabs).^2./trialabs);
   % robust distances
   %dists(i)=-sum(abs(obsab-trialabs))/length(obsab);
end
return;

function [freq,width]=convab(abunds,ma)
% 15 bins is upper limit covering abunds up to 2^14=16386, will only create as many as there are abunds for
% change the 3rd argument to 2 for Hubbell's version of Preston binning, to 1 for my version
[freq,e,c]=sadhist(abunds,15,2); 
if ma>0, %truncate to large abundances >ma - used for fitting theta
   lim=max(find(e(1:end-1)<ma));
   if ~isempty(lim), freq=freq(lim:end); end
elseif ma<0, % truncate to small abundances <|ma| - not currently used
   lim=min(find(e(2:end)>-ma));
   if ~isempty(lim), freq=freq(1:lim-1); end
end
freq=freq(:);
