% ESTIMATE: This function determines the best fit estimates from either a geometric, logseries, or poisson
%   distribution. The best fit parameter can be optimized by either a sum-of-squares or chi-squared criteria.
%
%   Usage: k = estimate(data,stat)
%
%   data = a [r x c] matrix of species abudances where the rows correspond to sites and the columns
%       correspond to species
%   fxn = a scalar to specify which function to use
%       1 = geometric distribution
%       2 = logseries
%       3 = Poisson distribution
%   stat = optionsal, speficies which optimization statistic to used in the fitting
%       0 = sum of absolute deviations {default}
%       1 = sum of squared deviations 
%       2 = chi-squared deviations
%   ------------------------------------------------------------------------------------------------
%   k = a [r x 1] vector containg the best estimate of "k" for each site
%
%   Chris L. Higgins 3/10/2003
%

% Made some modification 5/3/2003

function k = estimate(data,fxn,stat)

    if(nargin < 2)
        error('ESTIMATE: A distribution must be specified - geometric, logseries, or poisson!');
    end;
    if(nargin < 3)
        stat = [];
    end;
    
    if(isempty(stat))
        stat = 0;
    end;
    
    if(fxn == 1)
        kest = fminbnd('bestgeokf',0,1,[],data,stat);
        k = kest;
    end;
    if(fxn == 2)
        kest = fminbnd('bestlogkf',0,1,[],data,stat);
        k = kest;
    end;
    if(fxn == 3)
        kest = 0.5;
        kest = fminsearch('bestpoikf',kest,[],data,stat);
        k = kest;
    end;
           
return;