function [theta,m,phin,preston,d]=estimate_anal_ZSM_theta(data)
%[theta,m,phin,preston]=estimate_anal_ZSM_theta(data)
%
%estimates theta & m in a more direct way then Volket et al Nature 424:1035-1037
% their approach is implemented in the function estimate_anal_ZSM
% that approach attempts to eliminate theta as a parameter by using S
% instead - this results in fairly length and sometimes numerically
% unstable calculations (found in solvetheta). A more direct approach is to
% optimize on theta and m simulatenously - the method given here.
%
% WARNING - although performing better than the estimate_anal_ZSM routine for
% small values of m, it still has some problems with very small m 
% If you get back an m very close to 0.01 or smaller, beware
%
% written by Brian McGill who should be cited if you use this code for a 
% publication. Contact mail@brianmcgill.org if you have any comments or suggestions

J=sum(data);
%calculate initial theta guess using fisher's alpha
c=fminbnd(inline(['((1-x)/x*(-log(1-x))-' num2str(length(data)/J) ')^2'],'x'),0.0001,0.9999999);
alpha=J*(1-c)/c;
%TolX & TolFun must be met to fall out, make TolFun less restrictive
[params,d]=fminsearch(@dist,[0.3 alpha],optimset('Display','iter','TolX',0.001,'TolFun',0.01,'maxiter',200),data);
m=params(1);
theta=params(2);
[phin,preston]=getphi(theta,m,sum(data),max(data),length(data));



function d=dist(params,data)
persistent oldd;
m=params(1);
theta=params(2);
if m<0 | m>1 | theta<0, d=oldd*1.5; return; end %steep penalty past boundaries
[phin,pdf]=getphi(theta,m,sum(data),max(data),length(data));
actpdf=sadhist(data,50,2)'; %the 50=maximum # bins - just needs to be bigger than actual
%actpdf=sadhist(data,50,1)'; %use this version for no preston binning
%Volkv log chi2 version
d=sum((actpdf-pdf).^2./pdf);
%Original Hubbell generic likelihood version (use -log likelihood since we
%are minimizing
%nzobs=find(actpdf>0);d=-sum(actpdf(nzobs).*log(pdf(nzobs)./actpdf(nzobs)))-sum((pdf-actpdf));
%true likelihood - again through in a - since minimizing
%d=-sum(log(phin(data)));
oldd=d; %save it for out of bounds cases
%put in some penalties for m & theta out of bounds
thetalo=0.01;mlo=0.00001;mhi=0.9999;
if theta<thetalo, d=d*thetalo/theta; return; end
if m<mlo, d=d*mlo/m; return; end
if m>mhi, d=d*(1-mhi)/(1-m); return; end
return;
