% GEOKEST: This function estimates the k parameter of the geometric series that best fits
%   the data. This function was created based on the worked example #2 in Magurran (p.130)
%
%   Usage: kEst = bestgeok(data)
%
%   data = a [r x c] matrix of species abudances where the rows correspond to sites and the columns
%       correspond to species
%   -----------------------------------------------------------------------------------------------------
%   kEst = a [r x 1] vector containg the best estimate of "k" for each site
%
%   Chris L. Higgins 3/5/2003
%
%   Magurran, A.E. 1988. Ecological Diversity and Its Measurement. Princeton University
%       Press. Princeton, NJ. 179 pps.
%

function kEst = geokest(data)

    [r,c] = size(data);                                 % Determine size of data matrix
    kEst = zeros(r,1);                                  % Allocate k estimate vector
    
    for i = 1:r                                         % Cycle through each "site"
        ind = find(data(i,:) > 0);                      % Find the species with positive abundance
        Y = data(i,ind);                                % Pull those species into another vector
        Y = abs(sort(-Y));                              % Rank species according to abundance from high to low
        S = length(ind);                                % Calculate species richness 
        N = sum(Y);                                     % Calculate total number of individuals
        
        X = min(Y)/N;                                   % Calculate proportion of least abundant species
        
        stop = 0;                                       % Set stopping criteria or while loop
        k = 0;                                          % Set k equal to zero for each site
        while(stop == 0)
            k = k + .001;                               % Increase k incremently
            z = (k/(1-k)) * ((1-k)^S) / (1-(1-k)^S);    % use equation in ,Magurran
            if(round(z*1000) == round(X*1000))          % Determine if k equals z
                stop = 1;
            end;
        end;
        kEst(i) = k;                                    % Add k estimate into vector
    end;
            
return;