% GEOMETRIC: This function provides abundance data that follows a geometric series.
%
%   Uasge:  Abundance = geometric(S,N,k,c)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   k = optional, the proportion of the remaining resources that each new species consumes {default = 0.5}
%   c = optional, specifies whether or not to take the ceiling of the abundance distribution {default = 0}
%   -------------------------------------------------------------------------------------------------------
%   Abundance = a vector containing abundances according to the geometric distribution
%
%   Chris L. Higgins 3/5/2003
%
%   Magurran, A.E. 1988. Ecological Diversity and Its Measurement. Princeton University
%       Press. Princeton, NJ. 179 pps.
%

% 3/18/2003 add anoption to take the ceiling of the abundance distribution

function Abundance = geometric(S,N,k,c)

    if(nargin < 3)
        k = [];
    end;
    if(nargin < 4)
        c = [];
    end;
    
    if(isempty(k))
        k = 0.5;
    end;
    if(isempty(c))
        c = 0;
    end;

    Abundance = zeros(1,S);
    
    for i = 1:S
        x(i) = k * (1 - k)^(i-1);
        %Abundance(i) = N * (1 - (1 - k)^S)^-1 * k * (1 - k)^(i-1);
    end;
    y = x / sum(x);
    Abundance = N .* y;
    
    if(c == 1)
        Abundance = ceil(Abundance);
    end;
    
return;