% JACCARD: Calculates the Jaccard similarity index.
%
%   Usage:  Cs = jaccard(X)
%
%           X = [sites x species] presence/absence matrix
%           -------------------------------------------------------------------
%           Cs = [sites x sites] symmetric matrix of indices
%
%   Chris L. Higgins 7/16/2004
%
%   Magurran, A.E. 2004.  Measuring Biological Diversity. Blackwell Publishing.
%       Malden, MA. 256 pps.
%

function Cs = jaccard(X,sing)

    B = isbinary(X);
    if(B == 0)
        X = makebinary(X);
        warning('JACCARD: The data matrix was converted to a presence/absence matrix');
    end;
    
    if(nargin < 2)
        sing = [];
    end;
    if(isempty(sing))
        sing = 0;
    end;

    [r,c] = size(X);
    Tot = rowsum(X);
    Cs = ones(r,r);
    
    if(sing == 0)
        for i = 1:(r-1)
            for j = (i+1):r
                a = sum(X(i,:) & X(j,:));
                b = sum(X(i,:) & ~X(j,:));
                c = sum(~X(i,:) & X(j,:));
                if(a == 0 & b == 0 & c == 0)
                    Cs(i,j) = 0;
                else;
                    Cs(i,j) = a / (a + b + c);
                end;
                Cs(j,i) = Cs(i,j);
            end;
        end;
    end;
    
    if(sing ~= 0)
        V = 0;
        for i = 1:(r-1)
            for j = (i+1):r
                V = V + (Tot(i) + Tot(j) - (2*(sum(X(i,:) & X(j,:)))));
            end;
        end;       
        Cs = sum(V)/r;
    end;
    
return;