% LOGNORMAL: This function provides abundance data that follows a lognormal distribution.
%
%   Uasge:  Abundance = geometric(S,N)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   -------------------------------------------------------------------------------------------------------
%   Abundance = a vector containing abundances according to the lognormal distribution
%
%   Chris L. Higgins 4/21/2003
%
%   Krebs, C.J. 1989. Ecological Methodology. Harper and Row Publishers. New York, NY.
%       654 pps.
%   Ludwig, J.A. and J.F. Reynolds. 1988. Statistical Ecology. John Wiley and Sons. New York,
%       NY. 337 pps.
%   Magurran, A.E. 1988. Ecological Diversity and Its Measurement. Princeton University
%       Press. Princeton, NJ. 179 pps.
%

function Abundance = lognormal(S,N)

    a = 0.2;                            % Set a = 0.2 according to Magurran, Krebs, and Ludwig & Reynolds
    So = (S*a) / 1.772454;              % Based on eq. 10.14 in Krebs & eq. 7.5 in Ludwig & Reynolds

    ln = log2(N);    
    octave = 2.^[0:ln];
    R = [1:length(octave)-1] - (ceil((length(octave)-1)/2));

    param = fminsearch('lognormalf',[a So],[],R,S);    
    a = param(1);
    So = param(2);
    
    for i = 1:length(R)
        ExpS(i) = So * exp(-a^2 * R(i)^2);  % Calculates the expected number of species in the Rth octave
    end;

%    E = ceil(ExpS)
    E = round(ExpS)
    Abundance = [];
    
    for i = 1:length(R)
        x = octave(i):octave(i+1)-1;        % Produces a vector of potential number of individuals within each octave
        r = unidrnd(length(x),1,E(i));
        y = x(r);
        Abundance = [Abundance y];
    end;
    
return;