%MANOVAPAIR:	Performs all possible pairwise combinations of manovas given a data
%					set and a grouping vector. 
%
%	USAGE:	[max_p,prob] = manovapair(data,grps)
%
%				max_p = 	the maximum p-value for all possible pairwise manovas
%				prob = 	a square matrix containing the p-values for all pairwise manovas
%				--------------------------------------------------------------------------
%				data = 	a data matrix
%				grps = 	a grouping vector
%
%	Chris Higgins
%
%	REQUIRES: unique1, manova
%

function [max_p,prob,X] = manovapair(data,grps,iter)

    if(nargin < 3)
        iter = [];
    end;
	
	[u,freq] = unique1(grps);
   lenu = length(u);
   prob = zeros(lenu,lenu);
   
   for i = 1:lenu
      for j = 1:lenu
          Ind1 = find(grps == i);
          Ind2 = find(grps == j);
         if(i ~= j)
            [lambda,F,pr] = manova(data([Ind1; Ind2],:),grps([Ind1; Ind2]),iter);
            prob(i,j) = [pr];
         end;
         if(i == j)
            prob(i,j) = nan;
         end;  
	   end;
   end;
   
   max_p = max(max(prob));
   [c,i,j] = trilow(prob);
   [signif,critlim] = seqbonf(c);
   
   X = [i j signif c critlim];
   
return;
