% MAXPACK: This function, when given a presence-absence matrix, rearranges the rows and columns  
%   according to the code provided by Wirt Atmar. Thus, this program is completely analagous to the
%   nestedness Calculator - it produces identical maximally packed matrices!!!!!
%
%   Usage: [packed,richness,occurence] = maxpack(data)
%
%   data = a [r x c] presence-absence data matrix where rows = sites and columns = species
%   ---------------------------------------------------------------------------------------
%   packed = a presence-absence data matrix that is "maximally packed"
%   richness = a vector of species richness values corresponding to the packed matrix
%   occurence = a vector of species occurences corresponding to a packed matrix
%
%   Chris Higgins 3/7/2003
%
%   Atmar,W. and B.D. Patterson. 1993. The measure of order and disorder in the distribution
%       of species in fragmented habitat. Oecologia 96:373-382.
%

function [packed,richness,occurence] = maxpack(data)

    [islands,species] = size(data);                 % Determine total number of islands and species
    
    if(species > islands)
        Rpacked = data;
        for fold = 1:8
            Cpacked = sortcol(Rpacked);
            Rpacked = sortrow(Cpacked);
        end;
        packed = Rpacked;
    else;
        Cpacked = data;
        for fold = 1:8
            Rpacked = sortrow(Cpacked);
            Cpacked = sortcol(Rpacked);
        end;
        packed = Cpacked;
    end;

    richness = rowsum(packed);                      % Calculate the species richness for all sites
    occurence = sum(packed);                        % Calculate the occurences for all site
    
    non0rows = find(richness ~= 0);                 % Remove any rows that contain all zeros
    packed = packed(non0rows,:);
    
    non0cols = find(occurence ~= 0);                % Remove any columns that contain all zeros
    packed = packed(:,non0cols);

    [r,c] = size(packed);   
    all1rows = find(richness == c);                 % Remove any redundant all black rows
    lenR = length(all1rows);
    if(lenR > 1)
        packed = packed([lenR:r],:);
    end;
    
    all1cols = find(occurence == r);                % Remove any redundant all black columns
    lenC = length(all1cols);
    if(lenC > 1)
       packed = packed(:,[lenC:c]);
    end;
    
    richness = rowsum(packed);                      % Calculate the species richness for all sites
    occurence = sum(packed);                        % Calculate the occurences for all site
    
return;