% MORISITAHORN: Calculates the Morisita-Horn similarity index.
%
%   Usage:  Cn = morisitahorn(X)
%
%           X = [sites x species] matrix of abundances
%           -------------------------------------------------------------------
%           Cn = [sites x sites] symmetric matrix of indices
%
%   Chris L. Higgins 7/16/2004
%
%   Magurran, A.E. 2004.  Measuring Biological Diversity. Blackwell Publishing.
%       Malden, MA. 256 pps.
%

function Cn = morisitahorn(X)

    [r,c] = size(X);
    Tot = rowsum(X);
    Cn = ones(r,r);
    
    for i = 1:(r-1)
        for j = (i+1):r
            da = sum(X(i,:).^2)/Tot(i)^2;
            db = sum(X(j,:).^2)/Tot(j)^2;
            Cn(i,j) = 2*sum((X(i,:).*X(j,:))) / ((da + db)*(Tot(i)*Tot(j)));
            Cn(j,i) = Cn(i,j);
        end;
    end;
    
return;