% NESTEDNESSF: This function calculates the nestedness metric (Nc) and its standardization (C)
%   proposed by Wright and Reeves (1992).  The metric "counts the number of times that a species'
%   presence at a site correctly predicts its presence at richer sites, and sums these counts across
%   species and sites." THIS IS THE OJECTIVE FUNCTION FOR NESTEDNESS
%
%   usage: [No,N1,Nc] = nestednessf(X,H0,iter)
%
%   X = a data matrix (rows = sites & columns = species)
%   ------------------------------------------------------------------------------------------------
%   N0 = the number of absences from biotas richer than the most depauperate site on which it occurs
%   N1 = number of presences of a species at sites more impoverished than the richest 
%   Nc = the nestedness metric
%   C = the standardized nestedness matrix (independent of matrix size)
%   z = z score for the Nc metric
%   P = P-value for the Nc metric 
%
%   Chris L. Higgins 3/17/2004
%
%   Wright,D.H. and J.H. Reeves.  1992.  On the meaning and measuremment of nestedness of species
%       assemblages.  Oecologia, 92: 416-428.
%

function [N0,N1,Nc] = nestednessf(X,H0,iter)

    if(nargin < 2)
        H0 = [];
    end;
    if(nargin < 3)
        iter = [];
    end;
    
    if(isempty(H0))
        H0 = 0;
    end;
    if(isempty(iter))
        iter = 1000;
    end;
    

    b = isbinary(X);
    if(b == 0)
        X = makebinary(X);
    end;
    
    [N0,PN0,PvN0] = nestn0(X,H0,iter);
    [N1,PN1,PvN1] = nestn1(X,H0,iter);
    [Nc,PNc,PvNc] = nestnc(X,1,H0,iter);
    
    N0 = [N0 PN0 PvN0];
    N1 = [N1 PN1 PvN1];
    Nc = [Nc PNc PvNc];
    
return;