%NESTEDSORTCOLS:

function Cpacked = nestedsortcols(data)

    [islands,species] = size(data);             % Determine the total number of islands and species

    z0 = zeros(species,2);
    z1 = zeros(species,2);
    Cpacked = zeros(islands,species);
    
    for c = 1:species                           % Cycle through each column or species
        s = 0;                                  % Set the sum of squared distances for each column presence to 0
        t = 0;                                  % Set the sum of squared distances for each column absence to 0
        for r = 1:islands
            if(data(r,c) >= 1)%==
                s = s + r^2;                    % Calculate sum of squared distances from top margin
            end;
            if(data(r,c) == 0)
                t = t + (islands - r + 1)^2;    % Calculate sum of squared distances from bottom margin
            end;
        end;
        z0(c,2) = t;                            % Keep track of squared distances for each column absence
        z1(c,2) = s;                            % Keep track of squared distances for each column presence
        z0(c,1) = c;                            % Create grouping vector of column absences SSD
        z1(c,1) = c;                            % Create grouping vector of column presences SSD
    end;
    
    for i = 1:species                           % Cycle through each column and its neighbor
        for j = i+1:species
            if(z1(j,2) > z1(i,2))               % If the SSD of presences is greater for the next column, switch the columns
                t1 = z1(i,1);
                t2 = z1(i,2);
                z1(i,1) = z1(j,1);
                z1(i,2) = z1(j,2);
                z1(j,1) = t1;
                z1(j,2) = t2;
            end;
            if(z0(j,2) < z0(i,2))               % If the SSD of absences is greater for the next row, switch the rows
                t1 = z0(i,1);
                t2 = z0(i,2);
                z0(i,1) = z0(j,1);
                z0(i,2) = z0(j,2);
                z0(j,1) = t1;
                z0(j,2) = t2;
            end;
        end;
    end;
    
    for i = 1:species                           % Replace the SSD values with current position indices
        z1(i,2) = i;
        z0(i,2) = i;
    end;
    
    for i = 1:species
        for j = i+1:species
            if(z1(j,1) < z1(i,1))
                t1 = z1(i,1);
                t2 = z1(i,2);
                z1(i,1) = z1(j,1);
                z1(i,2) = z1(j,2);
                z1(j,1) = t1;
                z1(j,2) = t2;
            end;
            if(z0(j,1) < z0(i,1))
                t1 = z0(i,1);
                t2 = z0(i,2);
                z0(i,1) = z0(j,1);
                z0(i,2) = z0(j,2);
                z0(j,1) = t1;
                z0(j,2) = t2;
            end;
        end;
    end;
    
    for i = 1:species
        z1(i,1) = i;
        z1(i,2) = (z1(i,2) + z0(i,2)) / 2;
    end;
    
    for i = 1:species
        for j = i+1:species
            if(z1(j,2) < z1(i,2))
                t1 = z1(i,1);
                t2 = z1(i,2);
                z1(i,1) = z1(j,1);
                z1(i,2) = z1(j,2);
                z1(j,1) = t1;
                z1(j,2) = t2;
            end;
        end;
    end;
    
    c0 = 0;
    for i = 1:species
        if(z1(i,1) ~= i)
            c0 = c0 + 1;
        end;
    end;
    
    if(c0 == 0)
        Cpacked = data;
    else;
        temp = zeros(islands,species);
        for r = 1:islands
            for c = 1:species
                temp(r,c) = data(r,z1(c,1));
            end;
        end;
        for r = 1:islands
            for c = 1:species
                Cpacked(r,c) = temp(r,c);
            end;
        end;
    end;

return;