% NESTEDSORTROWS:

function Rpacked = nestedsortrows(data)

    [islands,species] = size(data);                     % Determine the total number of islands and species

    z0 = zeros(islands,2);
    z1 = zeros(islands,2);
    Rpacked = zeros(islands,species);
    
    for r = 1:islands                                   % Cycle through each row or island
        s = 0;                                          % Set the sum of squared distances for each row presence to 0
        t = 0;                                          % Set the sum of squared distances for each row absence to 0
        for c = 1:species
            if(data(r,c) >= 1)%==
                s = s + c^2;                            % Calculate sum of squared distances from left margin
            end;
            if(data(r,c) == 0)
                t = t + (species - c + 1)^2;            % Calculate sum of squared distances from right margin
            end;
        end;
        z0(r,2) = t;                                    % Keep track of squared distances for each row absence
        z1(r,2) = s;                                    % Keep track of squared distances for each row presence
        z0(r,1) = r;                                    % Create grouping vector of row absences SSD
        z1(r,1) = r;                                    % Create grouping vector of row presences SSD
    end;

    for i = 1:islands                                   % Cycle through each row and its neighbor
        for j = i+1:islands
            if(z1(j,2) > z1(i,2))                       % If the SSD of presences is greater for the next row, switch the rows
                t1 = z1(i,1);
                t2 = z1(i,2);
                z1(i,1) = z1(j,1);
                z1(i,2) = z1(j,2);
                z1(j,1) = t1;
                z1(j,2) = t2;
            end;
            if(z0(j,2) < z0(i,2))                       % If the SSD of absences is greater for the next row, switch the rows                  
                t1 = z0(i,1);
                t2 = z0(i,2);
                z0(i,1) = z0(j,1);
                z0(i,2) = z0(j,2);
                z0(j,1) = t1;
                z0(j,2) = t2;
            end;
        end;
    end;
    
    for i = 1:islands
        z1(i,2) = i;
        z0(i,2) = i;
    end;
    
    for i = 1:islands
        for j = i+1:islands
            if(z1(j,1) < z1(i,1))
                t1 = z1(i,1);
                t2 = z1(i,2);
                z1(i,1) = z1(j,1);
                z1(i,2) = z1(j,2);
                z1(j,1) = t1;
                z1(j,2) = t2;
            end;
            if(z0(j,1) < z0(i,1))
                t1 = z0(i,1);
                t2 = z0(i,2);
                z0(i,1) = z0(j,1);
                z0(i,2) = z0(j,2);
                z0(j,1) = t1;
                z0(j,2) = t2;
            end;
        end;
    end;
    
    for i = 1:islands
        z1(i,1) = i;
        z1(i,2) = (z1(i,2) + z0(i,2)) / 2;
    end;
    
    for i = 1:islands
        for j = i+1:islands
            if(z1(j,2) < z1(i,2))
                t1 = z1(i,1);
                t2 = z1(i,2);
                z1(i,1) = z1(j,1);
                z1(i,2) = z1(j,2);
                z1(j,1) = t1;
                z1(j,2) = t2;
            end;
        end;
    end;
    
    c0 = 0;
    for i = 1:islands
        if(z1(i,1) ~= i)
            c0 = c0 + 1;
        end;
    end;
    
    if(c0 == 0)
        Rpacked = data;
    else;
        temp = zeros(islands,species);
        for r = 1:islands
            for c = 1:species
                temp(r,c) = data(z1(r,1),c);
            end;
        end;
        for r = 1:islands
            for c = 1:species
                Rpacked(r,c) = temp(r,c);
            end;
        end;
    end;
    
return;    