% NESTSORT:  This function sorts a presence-absence data matrix by species richness and occurences.
%
%   [packed,Ir,Io] = nestsort(X)
%
%   X = a [site x species] presence-absence data matrix
%   -----------------------------------------------------------------------------------------------
%   packed = the sorted data matrix
%   Ir = indices for the rearranged sites
%   Io = indices for the rearranged species
%
%   Chris L. Higgins
%

function [packed,Ir,Io] = nestsort(X)

    richness = rowsum(X);                           % Calculate the species richness for all sites
    occurence = sum(X);                             % Calculate the occurences for all site
    
    [Y,Ir] = sort(-richness);                       % Sort rows by decreasing richness
    packed = X(Ir,:);

    [Y,Io] = sort(-occurence);                      % Sort columns by decreasing occurences
    packed = packed(:,Io);
    
return;