% NULLSP: This function produces a null model matrix based on a random draw of "n" species
%   from the regional speces pool for each of the sites (rows) in the matrix
%
%   Usage: null = nullsp(presence)
%
%   presence = an [r x c] presence/absence data matrix with rows corresponding to sites and 
%       columns corresponding to species
%   --------------------------------------------------------------------------------------------
%   null = an [r x c] presence/absence data matrix based on random species from the species pool
%
%   Chris L. Higgins 2/17/2003
%

function null = nullsp(presence)

    rand('state',sum(100*clock))                    % Resets rand to a different state each time    

    [r,c] = size(presence);                         % Determie size of presence/absence matrix
    
    richness = rowsum(presence);                    % Calculate species richness for each site
    occurance = sum(presence);                      % Calculate occurance for each species
    
    species = makegrps([1:c],1);                    % Create a species list

    null = zeros(r,c);                              % Allocate a null matrix equal size to "presence"
    
    for a = 1:r
        rperm = randperm(c);                        % Randomly permute species list
        randdraw = rperm(1:richness(a));            % Randomly draw "n" species from regional pool
        null(a,randdraw) = 1;                       % Substitute 1s in place of 0s for random species
    end;
    
return;
        