% ORDINATE2: This function ordinates a matrix for analysis of meta-community structure.
%
%   Usage:  [Y,ir,ic] = ordinate2(X,ax)
%   
%       X = [sites x species] presence-absense data matrix
%       ax = optional, specifies which axis of correspondance to use in ordination {default = 1)
%       ---------------------------------------------------------------------------------------------
%       Y = [sites x species] ordinated data matrix
%       ir = vector of ordinated row indices
%       ic = vector of ordinated column indices
%
%   Chris Higgins 7/7/2004
%
%   As seen in -- Leibold, M.A. and G.M. Mikkelson. 2002. Coherence, species turnover, and boundary
%       clumping: elements of meta-community structure.  Oikos 97: 237 - 250.

function [Y,ir,ic] = ordinate2(X,ax)

    if(nargin < 2)                                      % Allocate input arguments
        ax = [];
    end;
    
    if(isempty(ax))
        ax = 1;
    end;
  
    %X = makebinary(X);                                  % Make sure data matrix is binary
    X = allzeros(X);                                    % Remove any rows or columns that contain all zeros
    
    [V,W] = CA(X);                                      % Perform correspondence analysis
    [r,ir] = sort(V(ax+1,:));                           % Sort eigenvectors by row
    [c,ic] = sort(W(ax+1,:));                           % Sort eigenvectors by column
    ir = fliplr(ir)';                                   % Add step to make matrix like Leibold and Mikkelson
    Y = X(ir,ic);                                       % Create ordinated matrix

return;