%PARALINE:  Provides the equation for the line that runs parallel to another line and through a given point
%
%   Usage: L = paraline(line,pt)
%
%   line = a line to which the new line is to run parallel to
%   pt = a point through which the new line is to pass 
%   -----------------------------------------------------------------------------------------
%   L = a new line that runs parallel to the original line and passes thorugh a given point
%
%   Chris L. Higgins 2/15/2003
%
%   Based on information provided in the appendix of The Red Book:
%
%   Bookstein, F.L., B. Chernoff, R.L. Elder, J.M. Humphries, G.R. Smith, and R.E. Strauss. 1985. Morphometrics
%       in Evolutionary Biology: the Geometry of Size and Shape Change.  Special Publication No.15, Philadelphia
%       Academy of Natural Sciences.  277 pp.


function L = paraline(line,pt)

    if(nargin < 2)
        error('PARALINE: A line and a point must be specified for function to work!');
    end;
    
    L = [line(1), line(2), -1*(pt(1)*line(1) + pt(2)*line(2))];
    
return;

    