%PATHITERM: 	Determines the number of observations per group it takes to make the 
%					Mahalanobis distance converge to the true value
%
%	USAGE:		obs = 	pathiter(p,diff,n,inc,max)
%
%					obs =		the number of observations per group
%					------------------------------------------------------------
%					p = 		the pair of specified search tactics
%					diff = 	optional, the acceptable difference between distances
%									{default = 0.1}
%					n =		optional, the number of consective significant differences
%									{default = 3}
%					inc = 	optional, the increment increase in observations {default = 50}
%					max = 	optional, the maximum number of iterations {default = 10000}
%
%	Chris Higgins 5/24/2000
%
%	REQUIRES: pathdata, mahal

function obs = pathiterm(p,diff,n,inc,max)

	if(nargin < 1)
      error('PATHITERM: A pair of search tactics must be specified.');
   end;
   if(nargin < 2)
      diff = [];
   end;
   if(nargin < 3)
      n = [];
   end;
   if(nargin < 4)
      inc = [];
   end;
   if(nargin < 5)
      max = [];
   end;
   
   if(isempty(diff))
      diff = 0.1;
   end;
   if(isempty(n))
      n = 3;
   end;
   if(isempty(inc))
      inc = 50;
   end;
   if(isempty(max))
      max = 10000;
   end;

   
	a = 0;
	dist = 0;
   len = 0;
   
	while(len < n)
      a = a + 1;
      ngrp = a * inc;
      [data,grps] = pathdata(p,ngrp);
      D = mahal(data,grps);
      differ = abs(D(1,2) - dist);
      dist = D(1,2);
      if(differ < diff)
         len = len + 1;
      else
         len = 0;
      end;
   	obs = ngrp   
   end;