% PEARSON:

function [ind,dist] = pearson(pts,size,close,step,r)

    if(nargin < 2)										% Allocate input arguments
        size = [];
    end;
    if(nargin < 3)
        close = [];
    end;
    if(nargin < 4)
        step = [];
    end;
    if(nargin < 5)
        r = [];
    end;
      
   if(isempty(size))									% Assign values to input arguments
      size = 50;
   end;
   if(isempty(close))
      close = 0.05 * size;
   end;
   if(isempty(step))
       step = close;
   end;
   if(isempty(r))
       r = 0;
   end;
   
   len = length(pts);								    % Calculate number of food items to consume
   
   len1 = 0;											% Allocate matrices
   w = zeros(1,2);
   border = [0 0;0 size;size size;size 0];
   walk = [0 0];
   randtheta = 0;
   dist = 0;
   find = 0;
   start = [0 0];
   stepdist = 0;
   
   while(find == 0)  

% Generate turning angles.
        if(r == 0)
            theta = rand .* pi; 			                % 	Generate uniform random angle
            rnd = round(rand);
            if(rnd == 0)
                thetha = -theta;
            end;
            randtheta = randtheta + theta;
        end;      
        if(r == 1)
            theta = rand .* (pi ./ 2);                      %   Generate uniform angle with AMT of 180
            rnd = round(rand);
            if(rnd == 0)
                theta = -theta;
            end;
            randtheta = randtheta + theta;
        end;
        if(r == 2)                                          % Generate turn angle form normal dist. with sd = pi/4
            a = 0;
            while(a == 0)
                theta = normrnd(0,(pi./4));
                if(-pi < theta < pi)
                a = 1;
                end;
            end;
            randtheta = randtheta + theta;
        end;
      
        if(randtheta > pi)                                  % Alter angle to allow for correct coordinates
            randtheta = randtheta - (2 * pi);
        end;
        if(randtheta < -pi)
            randtheta = randtheta + (2 * pi);
        end; 
      
        steplength = step;							        % 	Generate constant step length	
	  
        x = sin(randtheta) .* steplength;                   % 	Calculate coordinates of new step
        y = cos(randtheta) .* steplength;	
      
        w(1) = walk(1) + x;							        % 	Calculate possible walk from new step
        w(2) = walk(2) + y;							
      
        isin = isinpoly(w,border);					        %	Determine if the new step is within the 
      													    % 		boundaries of the arena
      
        if(isin == 1)									    % 	If new step is within boundaries:
         
% Calculate the vertices of the rectangular area created from the perceptual range
%	during the step

            if(0 <= randtheta < pi)
                z = abs(90 - randtheta);
	            a = [walk(1)+(cos(z)*close)  walk(2)-(sin(z)*close)];
   	            b = [walk(1)-(cos(z)*close)  walk(2)+(sin(z)*close)];
      	        c = [w(1)+(cos(z)*close)  w(2)-(sin(z)*close)];
                d = [w(1)-(cos(z)*close)  w(2)+(sin(z)*close)];
            else
                z = abs(270 - randtheta);
                a = [walk(1)+(cos(z)*close)  walk(2)-(sin(z)*close)];
   	            b = [walk(1)-(cos(z)*close)  walk(2)+(sin(z)*close)];
      	        c = [w(1)+(cos(z)*close)  w(2)-(sin(z)*close)];
                d = [w(1)-(cos(z)*close)  w(2)+(sin(z)*close)];             
            end;
         
            isX = isinpoly(pts,[a;b;c;d]);					% See if any food items are with range
         
% If any food items are within the perceptual range of the animal while it is moving,
%	the animal will consume the first food item it recognizes       

		    if(any(isX == 1))
                d=zeros(len,1);
                for j = 1:len									% Calculate distance from food items
                    d(j) = euclidist(walk,pts(j,:));
                end;
                [m,ind] = min(d);
                walk(1) = pts(ind,1);					    % Add movement to food as new step 
         		walk(2) = pts(ind,2);
                stepdist = ptsdist(start,walk); 
                find = 1;
            end;
         
% If no food items are within the perceptual range durning move, then finish step
         
            if(all(isX == 0))
                walk(1) = w(1);							% Add new step to walk
         	    walk(2) = w(2);
      	        for i = 1:len								% Calculate distance from food items
      		  	    d(i) = euclidist(w,pts(i,:));
     	        end;
        		[m,ind]=min(d);								% Determine which food item is closest
              	
% If at the end of a step, food items are within the perceptual range, then
%	the animal will consume and thus move to the closest food item
         
         	    if(m <= close)							
                    walk(1) = pts(ind,1);					% Add movement to the food as a step 
         		    walk(2) = pts(ind,2);
                    stepdist = ptsdist(w,walk);
                    find = 1;
                end;
            end;
            stepdist = ptsdist(start,w);
            dist = dist + stepdist;
            start = w;
        end;
   end;
   
return;