% Poisson: This function provides abundance data that follow a logarithmic series.
%
%   Uasge:  Abundance = poisson(S,N)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   ----------------------------------------------------------------------------------------------
%   Abundance = 
%
%   Chris L. Higgins 2/17/2003
%
%

function Abundance = poisson(S,N,k,c)

    if(nargin < 3)
        k = [];
    end;
    if(nargin < 4)
        c = [];
    end;
    
    if(isempty(k))
        k = 1;
    end;
    if(isempty(c))
        c = 0;
    end;

    Abundance = zeros(1,S);
    
    for i = 1:S
        x(i) = (exp(-k) * k^i) / factorial(i);
    end;
    x = abs(sort(-x));
    y = x / sum(x);
    Abundance = N .* y;

    if(c == 1)
        Abundance = ceil(Abundance);
    end;
    
return;