% PVALUE: 	Calculates the p-value for a statistic and its distribution
%			  	
%	USAGE: 	p = pvalue(x,distrib,tail)
%
%   x = the test statistic
%   distrib = a distribution of test statistics
%   tail = optional, specifies either a one tail or a two tail test {default = 2}
%           1 = left tail test
%           2 = two tailed test
%           3 = right tailed test
%   ------------------------------------------------------------------------------------------
%   p = probability of obtaining values as extreme or more extreme than the test statistic
%
%   Chris L. Higgins 2/10/2003
%

function p = pvalue(x,distrib,tail)

	d = size(distrib);
   
    distrib = sort(distrib);
    if(nargin < 3)
        tail = [];
    end;
    if(isempty(tail))
      tail = 2;
    end;
      
    tot = length(distrib);
   
    if(tail == 1)
        p = sum(distrib <= x) ./ tot;
    end;
    if(tail == 2)
        pL = sum(distrib <= x) ./ tot;
        pR = sum(distrib >= x) ./ tot;
        if(pL < pR)
            p = 2*pL;
        else
            p = 2*pR;
        end;
        if(p > 1)
            p = 1;
        end;
    end;
    if(tail == 3)
        p = sum(distrib >= x) ./ tot;
    end;

return;