% RANDASSORT: This function provides abundance data that follows the random assortment model of Tokeshi.
%   "This model refers to a situation where abundances of different species are not mutually related
%   at all. This would be conceived of either as a result of non-correspondences between nich
%   apportionment and species abundance, or as a non-heirarchical, dynamic apportionment of niche
%   under a highly variable environment."
%
%   Uasge:  Abundance = randassort(S,N,rel)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   rel = optional, specifies whether or not to make the abundances relative {default = 0}
%   ------------------------------------------------------------------------------------------------
%   Abundance = a [S x 1] vector of expected species abundances 
%
%   Chris L. Higgins 3/5/2003
%
%   Tokeshi, M. 1990. Niche apportionment or random assortment: species abundance patters revisited.
%       Journal of Animal Ecology, 59: 1129-1146.       
%

function Abundance = randassort(S,N,c,rel)

    if(nargin < 3)
        c = [];
    end;
    if(nargin < 4)
        rel = [];
    end;
    
    if(isempty(c))
        c = 0;
    end;
    if(isempty(rel))
        rel = 0;
    end;    

    Abundance = zeros(1,S);
 
    for i = 1:S
        RelAbund = (0.5^i)/(1-(0.5^S));
%        Abundance(i) = round(RelAbund * N);
        Abundance(i) = RelAbund * N;
    end;
    
    if(c == 1)
        Abundance = ceil(Abundance);
    end;
    
    if(rel ~=0)
        Abundance = Abundance / N;
    end;
    
return;