%RANDCIRCLE: Generate random points within a circle of specified radius,
%				centered on the origin.
%
%	USAGE: 	pts = randcircle(n,{radius},{center},{plotflag})
%
%				pts = the random points generated withina circle
%				----------------------------------------------------------
%				n = number of points
%				radius = optional, radius of circle {default = 1}
%				center = optional, center of teh circle {default = [0 0]}
%				plotflag = optional, boolean flag indicating, if true,
%						the points are to be plotted {default = 0}
%		
%	Chris Higgins 3/10/2000
%

function pts = randcircle(n,radius,center,plotflag)

	if(nargin < 1)
         error('RANDCIRCLE: The number of points must be specified.');
   end;
	if(nargin < 2)
		radius = [];
	end;
	if(nargin < 3)
		center = [];
   end;
   if(nargin < 4)
      plotflag = [];
   end;
   
	if(isempty(radius))
		radius = 1;
	end;
   if(isempty(center))
      center = [0 0];
   end;
   if(isempty(plotflag))
		plotflag = 0;
	end;
   
   pts = zeros(n,2);
   for i = 1:n
      while (pts(i) == [0 0])
         p = 2 * radius * rand(1,2) - [radius radius];   
         d = eucl(p,[0 0]);            
      	if (d <= radius)                    
        		pts(i,:) = p;
      	end;
    	end;
	end;
   pts = pts + ones(n,1) * center;
   
   if(plotflag == 1)
      plot(pts(:,1),pts(:,2),'o');
   end;
   
return;

