% RANDFRACT: This function provides abundance data that follows the random fraction model of Tokeshi.
%   In this model, "the niche is first divided at random (uniform) into two fractions, one of them
%   is then randomly chosen and divided at random(uniform) into further two fractions, thus resulting
%   in three fractions,... and so on."
%
%   Uasge:  Abundance = randfract(S,N,rel)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   rel = optional, specifies whether or not to make the abundances relative {default = 0}
%   ----------------------------------------------------------------------------------------
%   Abundance = a [S x 1] vector of expected species abundances 
%
%   Chris L. Higgins 3/5/2003
%
%   Tokeshi, M. 1990. Niche apportionment or random assortment: species abundance patters revisited.
%       Journal of Animal Ecology, 59: 1129-1146.       
%

function Abundance = randfract(S,N,rel)

    if(nargin < 3)
        rel = [];
    end;
    if(isempty(rel))
        rel = 0;
    end;    

    Abundance = zeros(1,S);
    
    x = [0 1];
        
    for i = 1:S-1
        in = randperm(i);
        ind = in(1);
        D = x(ind+1) - x(ind);
        r = rand * D;
        s = x(ind) + r;
        x = [x s];
        x = sort(x);
    end;

    for j = 1:S
        Ab(j) = (x(j+1) - x(j)) * N;
    end;
    
    Abundance = abs(sort(-Ab));

    if(rel ~=0)
        Abundance = Abundance / N;
    end;
    
return;