% RANDNEST: This function produces a randomized presence/absence matrix based on Jonsson (2001).  This
%   particular function relaxes two critical assumptions of traditionalo methods: (1) that the total
%   number of occurences in the matrix should be equal to the observed number in every randomly generated
%   matrix and (2) the row totoals (number of species per site) should be fixed.  BASED ON HIS ACTUAL CODE!!!
%
%   Usage:  null = randnest(X)
%
%   X = [sites x species] presence/absence data matrix
%   ---------------------------------------------------------------------------------------------------------------------------
%   null = [sites x species] randomized matrix of species presence/absence
%
%   Chris Higgins 9/29/2006
%
%   Jonsson,B.G.  2001.  A null model for randomization tests of nestedness in species assemblages.  Oecologia, 127: 309-313.
%

function null = randnest(X)

    [r,c] = size(X);                            % Determine size of data matrix
    
    Richness = rowsum(X);                       % Calcualte species richness
    Incidence = sum(X);                         % Calculate incidence for each species
    
    SpecFreq = Incidence/r;                     % Calcualte species frequencies
   
    null = zeros(r,c);                          % Allocate null matrix
    for i = 1:r
        for j = 1:c
            if(rand < SpecFreq(j))              % Generate random number between 0 and 1 -- if < than frequency occupy space
                null(i,j) = 1;
            end;
        end;
    end;
       
return;    