% RANDSAMP:  This function is used in the randomization part of PARTITION.
% It tests whether the observed partition of diversity could have been
% obtained by the random allocation of lower-level samples among
% higher-level samples.  In other words, could teh observed partition
% merely be a consequence of teh sampling design?
%
%   Usage:  null = randsamp(X,levels)
%
%   X = [sites x species] matrix of observed species abundances
%   levels = [sites x levels] matrix of group identifiers
%   ----------------------------------------------------------------------
%   null = [sites x species x levels] matrix of randomized abundances
%
%   Chris L Higgins 10/16/2007
%
%   Crist, T.O., J.A. Veech, J.C. Gering, and K.S. Summerville.  2003.
%       Partitioning species diversity across landscapes and regions: a
%       hierarchical analysis of alpha, beta, and gamma diversity.  The
%       American Naturalist 162(6): 734-743.
%

function [null,NullLevels] = randsamp(X,levels)

    [rX,cX] = size(X);                                  % Determine size of data matrix
    [rl,cl] = size(levels);                             % Determine number of levels
    
    GrpAll = ones(rl,1);                                % create grouping vector for all sites
    GrpEach = [1:rl]';
    Hierarchy = [GrpEach levels GrpAll];                % Combine levels and GrpAll
    %null = zeros(rX,cX,cl+1);                           % Allocate output matrix
    null(:,:,1) = X;
    null(:,:,cl+2) = X;
  
    
    NullLevels = [levels(:,cl) GrpAll];
    for i = cl+1:-1:2
        Z=[];
        [u2,f2] = unique1(Hierarchy(:,i));
        [u3,f3] = unique1(Hierarchy(:,i+1));
        for j = 1:length(u3)
            ind3 = find(Hierarchy(:,i+1) == u3(j));
            [u1,f1] = unique1(Hierarchy(ind3,i-1));
            R = randperm(length(u1));
            Y = Makegrps(u1(R),f1(R));
            Z = [Z;Y];
        end;
        NullLevels = [Z NullLevels];
    end;
    
    for i = 1:cl
        [u,f] = unique1(NullLevels(:,i));
        for j = 1:length(u)
            indN = find(NullLevels(:,i) == u(j));
            indH = find(Hierarchy(:,i) == u(j));
            null(indN,:,i+1) = X(indH,:);
        end;
    end;
    
 return;