% REPLACENULL:  This function creates a null model with which to assess species turnover. Ranges are allowed
%               to float randomly across a given set of sites.  Communities are allowed to float up and down 
%               a list of species.
%
%   USAGE: Null = replacenull(X,Comm)
%
%   X = [sites x species] incidence matrix
%   Comm = specifies whether to create a null based on ranges (0) or communities (1)
%   ----------------------------------------------------------------------------------------------------------
%   Null = null matrix
%
%   Chris L. Higgins 3/14/2005
%
%   Leibold,M.A. and Mikkelson,G.M.  2002.  Coherence, species turnover, and boundary clumping: elements 
%       of meta-community structure.  Oikos 97: 237-250.

function Null = replacenull(X,Comm)

    [sites,species] = size(X);
    Null = zeros(sites,species);
    
    
    if(Comm == 0)
        for i = 1:species
            ind1 = find(X(:,i) == 1);
            len1 = length(ind1);
            rd = ceil(rand*(sites-len1+1));
            Null([rd:rd+len1-1],i) = 1;
        end;
    end;
    
    if(Comm == 1)
        for i = 1:sites
            ind1 = find(X(i,:) == 1);
            len1 = length(ind1);
            rd = ceil(rand*(species-len1+1));
            Null(i,[rd:rd+len1-1]) = 1;
        end;
    end;

return;