% SADBIN: This function bins species abundances into a Preston type plot.
%
%   USAGE: N = sadbin(SAD,doplot)
%
%   SAD = a vector of species absolute abundance
%   doplot = {optional} specifies whether or not to plot the bins
%   ------------------------------------------------------------------------
%   N = the number of species that fall into each bin
%   edges = the edge of the bins
%
%   Chris L. Higgins 7/19/2005
%

function [N,edges] = sadbin(SAD,doplot)
   
    if(nargin < 2)
        doplot = [];
    end;
    
    if(isempty(doplot))
        doplot = 0;
    end;
    
    edges = [0 2.^(1:ceil(log2(max(SAD))))];
    centers = edges(1:end-1)+(edges(2:end)-edges(1:end-1))/2;
    [N,Bin] = histc(SAD,edges);
    for i = 2:(length(edges)-1),
        nfence = sum(SAD == edges(i));
        N(i-1) = N(i-1) + nfence/2;
        N(i) = N(i) - nfence/2;
    end;
    
    if(doplot)
        M = N(1:length(N)-1);
        bar(M);
    end;
    
return;
