% SGRATIO:
%
%   Usage: ratio = sgratio(Presence,Genus,iter)
%
%   Presence = a [r x c] matrix of species presences where sites correspond to rows and species correspond to columns
%   Genus = a vector of length c that tells which genus each species belongs to
%   iter = optional, specifies how many iterations to perform when determinig significance {default = 1000}
%   ------------------------------------------------------------------------------------------------------------------
%   ratio = a [r x 1] vector of Species/Genus ratios
%
%   Chris L. Higgins    3/3/2003
%

function [ratio,Pvalue] = sgratio(Presence,Genus,iter)

    if(nargin < 3)
        iter = [];
    end;
    
    [r,c] = size(Presence);                     % Determine the size of the adundance data matrix
    lenGenus = length(Genus);                   % Determine the length of the Genus vector
    if(c ~= lenGenus)
        error('SGRATIO: The Genera grouping vector must be the same length as the number of species');
    end;
    
    ratio = zeros(r,1);                         % Allocate vector for storing S/G ratios
    
    for i = 1:r
        ind = find(Presence(i,:) > 0);          % Determine which species are presesnt in the community
        G = Genus(ind);                         % Determine which genera are present in the community
        [u,f] = unique1(G);                     % Calculate the number of species per genus
        ratio(i) = mean(f);                     % Calculate the S/G ratio
    end;
    
    if(iter)
        Ratio = zeros(r,iter);
        Pvalue = zeros(r,1);
        for j = 1:iter
            null = nullsp(Presence);
            for k = 1:r
                ind = find(null(k,:) > 0);      % Determine which species are presesnt in the community
                G = Genus(ind);                 % Determine which genera are present in the community
                [u,f] = unique1(G);             % Calculate the number of species per genus
                Ratio(k,j) = mean(f);           % Calculate the S/G ratio
            end;
        end;
        for l = 1:r
            Pvalue(l) = pvalue(ratio(l),Ratio(l,:));
        end;
    end;
        
return;

