% SIMPSON: Returns a value of the Simpson diversity index for a vector of counts.
%
%  USAGE: [D,E] = simpson(X)
%
%         X = [Sites x Species] abundance matrix
%         --------------------------------------------------------
%         D = [Sites x 1] vector of Simpson diversity indices
%         E = [Sites x 1] vector of Simpson evenness indices  
%           
% Chris Higgins 7/27/2004
%
%   Simpson, E.H. 1949. Measurement of diversity. Nature, 163: 688.
%
%   Magurran, A.E. 2004.  Measuring Biological Diversity. Blackwell Publishing.
%       Malden, MA. 256 pps.

function [D,E] = simpson(X)

    [r,c] = size(X);                                        % Determine the number of sites
    if(r > 1 & c == 1)                                      % Convert column vector to row vector
        X = X';
        [r,c] = size(X);
    end;
    
    D = zeros(r,1);                                         % Allocate column vector for diversity indices
    E = zeros(r,1);                                         % Allocate column vector for evenness indices
    for i = 1:r
        ind = find(X(i,:) > 0);                             % Find all non-zero entries
        N = sum(X(i,ind));                                  % Calculate total number of individuals
        D(i) = sum((X(i,ind).*(X(i,ind)-1)) / (N.*(N-1)));  % Calculate Simpson diversity index
        E(i) = (1/D(i))/length(ind);                        % Calculate Ssimpson evenness index
    end;
  
return; 