% SNAILDDSE2: Density-dependent and spatially-explicit simulation for snail nestedness.
%
%   Usage: Y = snailddse2(X,extr,space)
%
%   X = [sites x species x seasons] original data matrix of snail assemblages
%   extr = extirpation rate between 0 and 1
%   space = [sites x  1] vector of disturbance
%       0 = not disturbed
%       1 = moderately disturbed
%       2 = heavily disturbed
%   -------------------------------------------------------------------------------
%   Y = [sites x species x seasons] matrix after density-dependent mortality
%
%   Chris L. Higgins 12/5/2006
%

function Y = snailddse2(X,extr,space)

    [r,c,d] = size(X);                              % determine size of input matrix
    
    Y = zeros(r,c,d);                               % allocate output matrix
    
    for i = 1:d                                     % cycle through each season
        for j = 1:r                                 % cycle through each site
            P = find(X(j,:,i) > 0);                 % determine which species are present
            N = sum(X(j,:,i));
            E = ceil(N * (extr * space(j)));
            grps = makegrps(P,X(j,P,i));
            if(~isempty(grps))
                r = randperm(N);
                G = remove(grps,r(1:E),[]);
                if(~isempty(G))
                    [u,f] = unique1(G);
                    Y(j,u,i) = f;
                end;
            end;
        end;
    end;
    
return