% SNAILDISE: Density-independent and spatially-explicit simulation for snail nestedness.
%
%   Usage: Y = snaildisd(X,extr,space)
%
%   X = [sites x species x seasons] original data matrix of snail assemblages
%   extr = extirpation rate between 0 and 1
%   space = [sites x  1] vector of disturbance
%       0 = not disturbed
%       1 = moderately disturbed
%       2 = heavily disturbed
%   -------------------------------------------------------------------------------
%   Y = [sites x species x seasons] matrix after density-independent mortality
%
%   Chris L. Higgins 12/5/2006
%

function Y = snaildise(X,extr,space)

    [r,c,d] = size(X);                              % determine size of input matrix
    
    Y = X;                                          % allocate output matrix
    
    for i = 1:d                                     % cycle through each season
        for j = 1:r                                 % cycle through each site
            P = find(X(j,:,i) > 0);                 % determine which species are present
            S = length(P);                          % estimate species richness for each site
            rnd = rand(1,S);                        % generate random numbers for each species
            ind = find(rnd <= (extr*space(j)));     % determine which species are extirpated
            Y(j,P(ind),i) = 0;                      % remove species from output matrix
        end;
    end;
    
return;