% SORENSEN: Calculates the Sorensen similarity index.
%
%   Usage:  Cn = sorensen(X)
%
%           X = [sites x species] presence/absence matrix
%           -------------------------------------------------------------------
%           Cn = [sites x sites] symmetric matrix of indices
%
%   Chris L. Higgins 7/16/2004
%
%   Magurran, A.E. 2004.  Measuring Biological Diversity. Blackwell Publishing.
%       Malden, MA. 256 pps.
%

function Cs = sorensen(X)

    [r,c] = size(X);
    Tot = rowsum(X);
    Cs = ones(r,r);
    
    for i = 1:(r-1)
        for j = (i+1):r
            a = sum(X(i,:) & X(j,:));
            b = sum(X(i,:) & ~X(j,:));
            c = sum(~X(i,:) & X(j,:));
            if(a == 0 & b == 0 & c == 0)
                Cs(i,j) = 0;
            else;
                Cs(i,j) = (2*a) / (2*a + b + c);
            end;
            Cs(j,i) = Cs(i,j);
        end;
    end;
    
return;