% TEMPSAD: This function is used for a study with Chris Bloch in which we are examining temporal changes in species-
%       abundance distributions.  The models that we are using are niche-based and dispersal-based, with different 
%       number of possible parameters.  Therefore, the degree of fit between the data and teh models must be assesed
%       with an information criterion (e.g., AIC)

function Y = tempsad(X,dev)

    [r,c] = size(X);                                    % Determine the number of seasons and species
    
    Diff = [];
    for i = 1:r
        ind = find(X(i,:) > 0);                         % Extract the species that were actually observed
        Obs = abs(sort(-X(i,ind)));                     % Create a sorted observed SAD
        BinObs = sadbin(Obs)
        S = length(Obs);                                % Calculate species richness
        N = sum(Obs);                                   % Calculate total number of individuals
        
        Exp1 = domindecay(S,N);                         % Create expected SAD based on Tokeshi's dominance decay model
        Bin1 = sadbin(Exp1);
        Exp2 = preemption(S,N);                         % Create expected SAD based on Tokeshi's dominance preemption model
        Bin2 = sadbin(Exp2);
        Exp3 = randassort(S,N);                           % Create expected SAD based on Tokeshi's random assortment model
        Bin3 = sadbin(Exp3);
        [theta,m] = esthub(Obs);                         % Estimate theta  and m for Hubbell's neutral model
        [mn,var,hLines]=myhubeng(theta,sum(X(r,:)),m);  % Create expected SAD based on Hubbell's model
        Exp4 = cell2mat(mn)';                            % Convert cell structure to matrix structure
        Bin4 = sadbin(Exp4);
        
        [NewB1,NewB2] = equallen(Bin1,Bin2)
        [NewB3,NewB2] = equallen(Bin3,Bin2)
        [NewB4,NewB2] = equallen(Bin4,Bin2)
        [NewBO,NewB2] = equallen(BinObs,Bin2)
        size(NewBO)
        size(NewB1)
        size(NewB2)
        size(NewB3)
        size(NewB4)
        
        Y = [NewBO; NewB1; NewB2; NewB3; NewB4];
        
        if(dev == 0)
            D1(i) = absdev(NewBO,NewB1);       % Calculate the sum-of-absolute-differences b/w Obs & Exp
            D2(i) = absdev(NewBO,NewB2);
            D3(i) = absdev(NewBO,NewB3);
            D4(i) = absdev(NewBO,NewB4);
        end;
        if(dev == 1)
            D1(i) = sumsqdev(NewBO,NewB1);     % Calculate the sum-of-squared-differences b/w Obs & Exp
            D2(i) = sumsqdev(NewBO,NewB2);
            D3(i) = sumsqdev(NewBO,NewB3);
            D4(i) = sumsqdev(NewBO,NewB4);
        end;
        if(dev == 2)
            D1(i) = chi2(NewBO,NewB1);         % Calculate the sum-of-chi-quared-differences b/w Obs & Exp
            D2(i) = chi2(NewBO,NewB2);
            D3(i) = chi2(NewBO,NewB3);
            D4(i) = chi2(NewBO,NewB4);
        end;
        
        D = [D1(i) D2(i) D3(i) D4(i)];
        D = D/sum(D);
        Diff = [Diff;D]
    end;
        
return;