% UNIFORM: This function provides abundance data that follows a uniform distribution of species
%   abundances. Simply put, the expected abundance for each species is the total number of
%   individuals divided (N) by species richness (S).
%
%   Usage: Abundance = uniform(S,N,c,rel)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   c = optional, specifies whether or not to take the ceiling of the abundance distribution {default = 0)
%   rel, optional, specifies whether or not to make the abudnance relative to N {default = 0}
%   -------------------------------------------------------------------------------------------------------
%   Abundance = a [S x 1] vector of expected species abundances 
%
%   Chris L. Higgins 3/5/2003
%

% 3/18/2003 add anoption to take the ceiling of the abundance distribution

function Abundance = uniform(S,N,c,rel)

    if(nargin < 3)
        c = [];
    end;
    if(nargin < 4)
        rel = [];
    end;
    
    if(isempty(c))
        c = 0;
    end;    
    if(isempty(rel))
        rel = 0;
    end;

    Abundance = ones(1,S) .* (N/S);
    
    if(c == 1)
        Abundance = ceil(Abundance);
    end;
    
    if(rel ~= 0)
        Abundance = Abundance / N;
    end;
    
return;
    