%COMPOSITE: This function provides the expected species abundances based on Tokeshi's (1990) composite model.
%   In this model, the first species exerts its dominance by prempting more than half the total niche available
%   and leaves the remainder to be exploited by the second species in the same manner, and so on until a 
%   threshold is reached.  AT that time, the abundances are based on a brokenstick model.
%
%   Uasge:  Abundance = composite(S,N,p)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   p = the percentage of species that exhibit premeption
%   ------------------------------------------------------------
%   Abundance = a [S x 1] vector of expected species abundances 
%
%   Chris L. Higgins 3/5/2003
%
%   Tokeshi, M. 1990. Niche apportionment or random assortment: species abundance patters revisited.
%       Journal of Animal Ecology, 59: 1129-1146.       
%

function Abundance = composite(S,N,p)
    
    if(nargin < 3)
        p = .25;
    end;
    if(p > 1)
        p = p / 100;
    end;
    
    Abundance = zeros(1,S);
    available = N;
    
    Sp = round(p*S);
    for i = 1:Sp
        stop = 0;
        while(stop == 0)
            r = rand;
            if(r >= 0.5)
                stop = 1;
            end;
        end;
        consumed = r * available;
        available = available - consumed;
        Abundance(i) = consumed;
    end;

    x = [0 1];
    for i = Sp+1:S-1
        in = rand;
        ind = find(x >= in);
        D = x(ind(1)) - x(ind(1)-1);
        r = rand * D;
        s = x(ind(1)-1) + r;
        x = [x s];
        x = sort(x);
    end;
    for j = 1:length(x)-1
        Ab(j) = (x(j+1) - x(j)) * available;
    end;
    Abund = abs(sort(-Ab));
    Abundance(Sp+1:S) = Abund;
return;
