% PREEMPTION: This function provides the expected species abundances based on Tokeshi (1990) model
%   of "Dominance Preemption." In this model, "the first species exerts its dominance by prempting
%   more than half the total niche available and leaves the remainder to be exploited by the second
%   species in the same manner, and so on." 
%
%   Uasge:  Abundance = preemption(S,N,rel)
%
%   S = the total number of species for each community
%   N = the total number of individuals in each community
%   rel = optional, specifies whether or not to make the abundances relative {default = 0}
%   ------------------------------------------------------------------------------------------------
%   Abundance = a [S x 1] vector of expected species abundances 
%
%   Chris L. Higgins 3/5/2003
%
%   Tokeshi, M. 1990. Niche apportionment or random assortment: species abundance patters revisited.
%       Journal of Animal Ecology, 59: 1129-1146.       
%

function Abundance = preemption(S,N,c,rel)

    if(nargin < 3)
        c =[];
    end;
    if(nargin < 4)
        rel = [];
    end;
    
    if(isempty(c))
        c = 0;
    end;
    if(isempty(rel))
        rel = 0;
    end;   
    
    Abundance = zeros(1,S);
    available = N;
    
    for i = 1:S
        stop = 0;
        while(stop == 0)
            r = rand;
            if(r >= 0.5)
                stop = 1;
            end;
        end;
        consumed = r * available;
        available = available - consumed;
        Abundance(i) = consumed;
    end;

    if(c == 1)
        Abundance = ceil(Abundance);
    end;
    
    if(rel ~=0)
        Abundance = Abundance / N;
    end;
    
return;